@@ -58,11 +58,11 @@ var resolveModule = function(names, mod, root) {
 
 var Couch = {
   // moving this away from global so we can move to json2.js later
-  compileFunction : function(source, ddoc, name) {
+  compileFunction : function(source, ddoc, name, sandbox) {
     if (!source) throw(["error","not_found","missing function"]);
 
     var functionObject = null;
-    var sandbox = create_sandbox();
+    var sandbox = sandbox || create_sandbox();
 
     var require = function(name, module) {
       module = module || {};
@@ -117,13 +117,7 @@ var Couch = {
     };
   },
   recursivelySeal : function(obj) {
-    // seal() is broken in current Spidermonkey
-    try {
-      seal(obj);
-    } catch (x) {
-      // Sealing of arrays broken in some SpiderMonkey versions.
-      // https://bugzilla.mozilla.org/show_bug.cgi?id=449657
-    }
+    seal(obj);
     for (var propname in obj) {
       if (typeof obj[propname] == "object") {
         arguments.callee(obj[propname]);
