@@ -21,71 +21,94 @@
 
 -include_lib("couch/include/couch_db.hrl").
 
--import(chttpd,
-    [send_json/2,send_json/3,send_method_not_allowed/2,
-    send_chunk/2,start_chunked_response/3]).
+-import(
+    chttpd,
+    [
+        send_json/2, send_json/3,
+        send_method_not_allowed/2,
+        send_chunk/2,
+        start_chunked_response/3
+    ]
+).
 
 % Node-specific request handler (_config and _stats)
 % Support _local meaning this node
-handle_node_req(#httpd{path_parts=[_, <<"_local">>]}=Req) ->
+handle_node_req(#httpd{path_parts = [_, <<"_local">>]} = Req) ->
     send_json(Req, 200, {[{name, node()}]});
-handle_node_req(#httpd{path_parts=[A, <<"_local">>|Rest]}=Req) ->
-    handle_node_req(Req#httpd{path_parts=[A, node()] ++ Rest});
+handle_node_req(#httpd{path_parts = [A, <<"_local">> | Rest]} = Req) ->
+    handle_node_req(Req#httpd{path_parts = [A, node()] ++ Rest});
 % GET /_node/$node/_versions
-handle_node_req(#httpd{method='GET', path_parts=[_, _Node, <<"_versions">>]}=Req) ->
+handle_node_req(#httpd{method = 'GET', path_parts = [_, _Node, <<"_versions">>]} = Req) ->
     IcuVer = couch_ejson_compare:get_icu_version(),
     UcaVer = couch_ejson_compare:get_uca_version(),
+    ColVer = couch_ejson_compare:get_collator_version(),
+    Hashes = crypto:supports(hashs),
     send_json(Req, 200, #{
-        erlang_version => ?l2b(?COUCHDB_ERLANG_VERSION),
+        erlang => #{
+            version => ?l2b(?COUCHDB_ERLANG_VERSION),
+            supported_hashes => Hashes
+        },
         collation_driver => #{
             name => <<"libicu">>,
-            library_version => version_tuple_to_str(IcuVer),
-            collation_algorithm_version => version_tuple_to_str(UcaVer)
+            library_version => couch_util:version_to_binary(IcuVer),
+            collation_algorithm_version => couch_util:version_to_binary(UcaVer),
+            collator_version => couch_util:version_to_binary(ColVer)
         },
         javascript_engine => #{
             name => <<"spidermonkey">>,
             version => couch_server:get_spidermonkey_version()
         }
     });
-handle_node_req(#httpd{path_parts=[_, _Node, <<"_versions">>]}=Req) ->
+handle_node_req(#httpd{path_parts = [_, _Node, <<"_versions">>]} = Req) ->
     send_method_not_allowed(Req, "GET");
-
 % GET /_node/$node/_config
-handle_node_req(#httpd{method='GET', path_parts=[_, Node, <<"_config">>]}=Req) ->
-    Grouped = lists:foldl(fun({{Section, Key}, Value}, Acc) ->
-        case dict:is_key(Section, Acc) of
-        true ->
-            dict:append(Section, {list_to_binary(Key), list_to_binary(Value)}, Acc);
-        false ->
-            dict:store(Section, [{list_to_binary(Key), list_to_binary(Value)}], Acc)
-        end
-    end, dict:new(), call_node(Node, config, all, [])),
-    KVs = dict:fold(fun(Section, Values, Acc) ->
-        [{list_to_binary(Section), {Values}} | Acc]
-    end, [], Grouped),
+handle_node_req(#httpd{method = 'GET', path_parts = [_, Node, <<"_config">>]} = Req) ->
+    Grouped = lists:foldl(
+        fun({{Section, Key}, Value}, Acc) ->
+            case dict:is_key(Section, Acc) of
+                true ->
+                    dict:append(Section, {list_to_binary(Key), list_to_binary(Value)}, Acc);
+                false ->
+                    dict:store(Section, [{list_to_binary(Key), list_to_binary(Value)}], Acc)
+            end
+        end,
+        dict:new(),
+        call_node(Node, config, all, [])
+    ),
+    KVs = dict:fold(
+        fun(Section, Values, Acc) ->
+            [{list_to_binary(Section), {Values}} | Acc]
+        end,
+        [],
+        Grouped
+    ),
     send_json(Req, 200, {KVs});
-handle_node_req(#httpd{path_parts=[_, _Node, <<"_config">>]}=Req) ->
+handle_node_req(#httpd{path_parts = [_, _Node, <<"_config">>]} = Req) ->
     send_method_not_allowed(Req, "GET");
 % POST /_node/$node/_config/_reload - Flushes unpersisted config values from RAM
-handle_node_req(#httpd{method='POST', path_parts=[_, Node, <<"_config">>, <<"_reload">>]}=Req) ->
+handle_node_req(
+    #httpd{method = 'POST', path_parts = [_, Node, <<"_config">>, <<"_reload">>]} = Req
+) ->
     case call_node(Node, config, reload, []) of
         ok ->
             send_json(Req, 200, {[{ok, true}]});
         {error, Reason} ->
             chttpd:send_error(Req, {bad_request, Reason})
     end;
-handle_node_req(#httpd{path_parts=[_, _Node, <<"_config">>, <<"_reload">>]}=Req) ->
+handle_node_req(#httpd{path_parts = [_, _Node, <<"_config">>, <<"_reload">>]} = Req) ->
     send_method_not_allowed(Req, "POST");
 % GET /_node/$node/_config/Section
-handle_node_req(#httpd{method='GET', path_parts=[_, Node, <<"_config">>, Section]}=Req) ->
-    KVs = [{list_to_binary(Key), list_to_binary(Value)}
-            || {Key, Value} <- call_node(Node, config, get, [Section])],
+handle_node_req(#httpd{method = 'GET', path_parts = [_, Node, <<"_config">>, Section]} = Req) ->
+    KVs = [
+        {list_to_binary(Key), list_to_binary(Value)}
+     || {Key, Value} <- call_node(Node, config, get, [Section])
+    ],
     send_json(Req, 200, {KVs});
-handle_node_req(#httpd{path_parts=[_, _Node, <<"_config">>, _Section]}=Req) ->
+handle_node_req(#httpd{path_parts = [_, _Node, <<"_config">>, _Section]} = Req) ->
     send_method_not_allowed(Req, "GET");
 % PUT /_node/$node/_config/Section/Key
 % "value"
-handle_node_req(#httpd{method='PUT', path_parts=[_, Node, <<"_config">>, Section, Key]}=Req) ->
+handle_node_req(#httpd{method = 'PUT', path_parts = [_, Node, <<"_config">>, Section, Key]} = Req) ->
     couch_util:check_config_blacklist(Section),
     Value = couch_util:trim(chttpd:json_body(Req)),
     Persist = chttpd:header_value(Req, "X-Couch-Persist") /= "false",
@@ -99,34 +122,36 @@ handle_node_req(#httpd{method='PUT', path_parts=[_, Node, <<"_config">>, Section
             chttpd:send_error(Req, {bad_request, Reason})
     end;
 % GET /_node/$node/_config/Section/Key
-handle_node_req(#httpd{method='GET', path_parts=[_, Node, <<"_config">>, Section, Key]}=Req) ->
+handle_node_req(#httpd{method = 'GET', path_parts = [_, Node, <<"_config">>, Section, Key]} = Req) ->
     case call_node(Node, config, get, [Section, Key, undefined]) of
-    undefined ->
-        throw({not_found, unknown_config_value});
-    Value ->
-        send_json(Req, 200, list_to_binary(Value))
+        undefined ->
+            throw({not_found, unknown_config_value});
+        Value ->
+            send_json(Req, 200, list_to_binary(Value))
     end;
 % DELETE /_node/$node/_config/Section/Key
-handle_node_req(#httpd{method='DELETE',path_parts=[_, Node, <<"_config">>, Section, Key]}=Req) ->
+handle_node_req(
+    #httpd{method = 'DELETE', path_parts = [_, Node, <<"_config">>, Section, Key]} = Req
+) ->
     couch_util:check_config_blacklist(Section),
     Persist = chttpd:header_value(Req, "X-Couch-Persist") /= "false",
     case call_node(Node, config, get, [Section, Key, undefined]) of
-    undefined ->
-        throw({not_found, unknown_config_value});
-    OldValue ->
-        case call_node(Node, config, delete, [Section, Key, Persist]) of
-            ok ->
-                send_json(Req, 200, list_to_binary(OldValue));
-            {error, Reason} ->
-                chttpd:send_error(Req, {bad_request, Reason})
-        end
+        undefined ->
+            throw({not_found, unknown_config_value});
+        OldValue ->
+            case call_node(Node, config, delete, [Section, Key, Persist]) of
+                ok ->
+                    send_json(Req, 200, list_to_binary(OldValue));
+                {error, Reason} ->
+                    chttpd:send_error(Req, {bad_request, Reason})
+            end
     end;
-handle_node_req(#httpd{path_parts=[_, _Node, <<"_config">>, _Section, _Key]}=Req) ->
+handle_node_req(#httpd{path_parts = [_, _Node, <<"_config">>, _Section, _Key]} = Req) ->
     send_method_not_allowed(Req, "GET,PUT,DELETE");
-handle_node_req(#httpd{path_parts=[_, _Node, <<"_config">>, _Section, _Key | _]}=Req) ->
+handle_node_req(#httpd{path_parts = [_, _Node, <<"_config">>, _Section, _Key | _]} = Req) ->
     chttpd:send_error(Req, not_found);
 % GET /_node/$node/_stats
-handle_node_req(#httpd{method='GET', path_parts=[_, Node, <<"_stats">> | Path]}=Req) ->
+handle_node_req(#httpd{method = 'GET', path_parts = [_, Node, <<"_stats">> | Path]} = Req) ->
     flush(Node, Req),
     Stats0 = call_node(Node, couch_stats, fetch, []),
     Stats = couch_stats_httpd:transform_stats(Stats0),
@@ -134,49 +159,54 @@ handle_node_req(#httpd{method='GET', path_parts=[_, Node, <<"_stats">> | Path]}=
     EJSON0 = couch_stats_httpd:to_ejson(Nested),
     EJSON1 = couch_stats_httpd:extract_path(Path, EJSON0),
     chttpd:send_json(Req, EJSON1);
-handle_node_req(#httpd{path_parts=[_, _Node, <<"_stats">>]}=Req) ->
+handle_node_req(#httpd{path_parts = [_, _Node, <<"_stats">>]} = Req) ->
     send_method_not_allowed(Req, "GET");
-handle_node_req(#httpd{method='GET', path_parts=[_, Node, <<"_prometheus">>]}=Req) ->
+handle_node_req(#httpd{method = 'GET', path_parts = [_, Node, <<"_prometheus">>]} = Req) ->
     Metrics = call_node(Node, couch_prometheus_server, scrape, []),
     Version = call_node(Node, couch_prometheus_server, version, []),
-    Type  = "text/plain; version=" ++ Version,
+    Type = "text/plain; version=" ++ Version,
     Header = [{<<"Content-Type">>, ?l2b(Type)}],
     chttpd:send_response(Req, 200, Header, Metrics);
-handle_node_req(#httpd{path_parts=[_, _Node, <<"_prometheus">>]}=Req) ->
+handle_node_req(#httpd{path_parts = [_, _Node, <<"_prometheus">>]} = Req) ->
     send_method_not_allowed(Req, "GET");
 % GET /_node/$node/_system
-handle_node_req(#httpd{method='GET', path_parts=[_, Node, <<"_system">>]}=Req) ->
+handle_node_req(#httpd{method = 'GET', path_parts = [_, Node, <<"_system">>]} = Req) ->
     Stats = call_node(Node, chttpd_node, get_stats, []),
     EJSON = couch_stats_httpd:to_ejson(Stats),
     send_json(Req, EJSON);
-handle_node_req(#httpd{path_parts=[_, _Node, <<"_system">>]}=Req) ->
+handle_node_req(#httpd{path_parts = [_, _Node, <<"_system">>]} = Req) ->
     send_method_not_allowed(Req, "GET");
 % POST /_node/$node/_restart
-handle_node_req(#httpd{method='POST', path_parts=[_, Node, <<"_restart">>]}=Req) ->
+handle_node_req(#httpd{method = 'POST', path_parts = [_, Node, <<"_restart">>]} = Req) ->
     call_node(Node, init, restart, []),
     send_json(Req, 200, {[{ok, true}]});
-handle_node_req(#httpd{path_parts=[_, _Node, <<"_restart">>]}=Req) ->
+handle_node_req(#httpd{path_parts = [_, _Node, <<"_restart">>]} = Req) ->
     send_method_not_allowed(Req, "POST");
-handle_node_req(#httpd{path_parts=[_, Node | PathParts],
-                       mochi_req=MochiReq0}) ->
+handle_node_req(#httpd{
+    path_parts = [_, Node | PathParts],
+    mochi_req = MochiReq0
+}) ->
     % strip /_node/{node} from Req0 before descending further
     RawUri = MochiReq0:get(raw_path),
     {_, Query, Fragment} = mochiweb_util:urlsplit_path(RawUri),
     NewPath0 = "/" ++ lists:join("/", [couch_util:url_encode(P) || P <- PathParts]),
     NewRawPath = mochiweb_util:urlunsplit_path({NewPath0, Query, Fragment}),
     MaxSize = chttpd_util:get_chttpd_config_integer(
-        "max_http_request_size", 4294967296),
+        "max_http_request_size", 4294967296
+    ),
     NewOpts = [{body, MochiReq0:recv_body(MaxSize)} | MochiReq0:get(opts)],
     Ref = erlang:make_ref(),
-    MochiReq = mochiweb_request:new({remote, self(), Ref},
-                               NewOpts,
-                               MochiReq0:get(method),
-                               NewRawPath,
-                               MochiReq0:get(version),
-                               MochiReq0:get(headers)),
+    MochiReq = mochiweb_request:new(
+        {remote, self(), Ref},
+        NewOpts,
+        MochiReq0:get(method),
+        NewRawPath,
+        MochiReq0:get(version),
+        MochiReq0:get(headers)
+    ),
     call_node(Node, couch_httpd, handle_request, [MochiReq]),
     recv_loop(Ref, MochiReq0);
-handle_node_req(#httpd{path_parts=[_]}=Req) ->
+handle_node_req(#httpd{path_parts = [_]} = Req) ->
     chttpd:send_error(Req, {bad_request, <<"Incomplete path to _node request">>});
 handle_node_req(Req) ->
     chttpd:send_error(Req, not_found).
@@ -207,12 +237,13 @@ recv_loop(Ref, ReqResp) ->
     end.
 
 call_node(Node0, Mod, Fun, Args) when is_binary(Node0) ->
-    Node1 = try
-                list_to_existing_atom(?b2l(Node0))
-            catch
-                error:badarg ->
-                    throw({not_found, <<"no such node: ", Node0/binary>>})
-            end,
+    Node1 =
+        try
+            list_to_existing_atom(?b2l(Node0))
+        catch
+            error:badarg ->
+                throw({not_found, <<"no such node: ", Node0/binary>>})
+        end,
     call_node(Node1, Mod, Fun, Args);
 call_node(Node, Mod, Fun, Args) when is_atom(Node) ->
     case rpc:call(Node, Mod, Fun, Args) of
@@ -232,15 +263,34 @@ flush(Node, Req) ->
     end.
 
 get_stats() ->
-    Other = erlang:memory(system) - lists:sum([X || {_,X} <-
-        erlang:memory([atom, code, binary, ets])]),
-    Memory = [{other, Other} | erlang:memory([atom, atom_used, processes,
-        processes_used, binary, code, ets])],
+    Other =
+        erlang:memory(system) -
+            lists:sum([
+                X
+             || {_, X} <-
+                    erlang:memory([atom, code, binary, ets])
+            ]),
+    Memory = [
+        {other, Other}
+        | erlang:memory([
+            atom,
+            atom_used,
+            processes,
+            processes_used,
+            binary,
+            code,
+            ets
+        ])
+    ],
     {NumberOfGCs, WordsReclaimed, _} = statistics(garbage_collection),
     {{input, Input}, {output, Output}} = statistics(io),
     {CF, CDU} = db_pid_stats(),
-    MessageQueues0 = [{couch_file, {CF}}, {couch_db_updater, {CDU}},
-        {couch_server, couch_server:aggregate_queue_len()}],
+    MessageQueues0 = [
+        {couch_file, {CF}},
+        {couch_db_updater, {CDU}},
+        {couch_server, couch_server:aggregate_queue_len()},
+        {index_server, couch_index_server:aggregate_queue_len()}
+    ],
     MessageQueues = MessageQueues0 ++ message_queues(registered()),
     {SQ, DCQ} = run_queues(),
     [
@@ -283,13 +333,15 @@ db_pid_stats(Mod, Candidates) ->
                         {Mod, init, 1} ->
                             case proplists:get_value(message_queue_len, PI) of
                                 undefined -> Acc;
-                                Len -> [Len|Acc]
+                                Len -> [Len | Acc]
                             end;
-                        _  ->
+                        _ ->
                             Acc
                     end
             end
-        end, [], Candidates
+        end,
+        [],
+        Candidates
     ),
     format_pid_stats(Mailboxes).
 
@@ -308,17 +360,40 @@ format_pid_stats(Mailboxes) ->
     ].
 
 get_distribution_stats() ->
-    lists:map(fun({Node, Socket}) ->
-        {ok, Stats} = inet:getstat(Socket),
-        {Node, {Stats}}
-    end, erlang:system_info(dist_ctrl)).
+    lists:map(
+        fun({Node, Socket}) ->
+            try inet:getstat(Socket) of
+                {ok, Stats} ->
+                    {Node, {Stats}}
+            catch
+                _:_ ->
+                    {Node,
+                        {[
+                            {recv_oct, 0},
+                            {recv_cnt, 0},
+                            {recv_max, 0},
+                            {recv_avg, 0},
+                            {recv_dvi, 0},
+                            {send_oct, 0},
+                            {send_cnt, 0},
+                            {send_max, 0},
+                            {send_avg, 0},
+                            {send_pend, 0}
+                        ]}}
+            end
+        end,
+        erlang:system_info(dist_ctrl)
+    ).
 
 message_queues(Registered) ->
-    lists:map(fun(Name) ->
-        Type = message_queue_len,
-        {Type, Length} = process_info(whereis(Name), Type),
-        {Name, Length}
-    end, Registered).
+    lists:map(
+        fun(Name) ->
+            Type = message_queue_len,
+            {Type, Length} = process_info(whereis(Name), Type),
+            {Name, Length}
+        end,
+        Registered
+    ).
 
 %% Workaround for https://bugs.erlang.org/browse/ERL-1355
 run_queues() ->
@@ -329,10 +404,3 @@ run_queues() ->
             [DCQ | SQs] = lists:reverse(statistics(run_queue_lengths)),
             {lists:sum(SQs), DCQ}
     end.
-
-version_tuple_to_str(Version) when is_tuple(Version) ->
-    List1 = tuple_to_list(Version),
-    IsZero = fun(N) -> N == 0 end,
-    List2 = lists:reverse(lists:dropwhile(IsZero, lists:reverse(List1))),
-    List3 = [erlang:integer_to_list(N) || N <- List2],
-    ?l2b(lists:join(".", List3)).
