@@ -13,62 +13,59 @@
 -module(config_tests).
 -behaviour(config_listener).
 
-
--include_lib("couch/include/couch_eunit.hrl").
--include_lib("couch/include/couch_db.hrl").
-
-
 -export([
     handle_config_change/5,
     handle_config_terminate/3
 ]).
 
+-include_lib("couch/include/couch_eunit.hrl").
+-include_lib("couch/include/couch_db.hrl").
 
 -define(TIMEOUT, 4000).
 -define(RESTART_TIMEOUT_IN_MILLISEC, 3000).
 
 -define(CONFIG_FIXTURESDIR,
-        filename:join([?BUILDDIR(), "src", "config", "test", "fixtures"])).
+    filename:join([?BUILDDIR(), "src", "config", "test", "fixtures"])
+).
 
 -define(CONFIG_DEFAULT_TEST,
-        filename:join([?CONFIG_FIXTURESDIR, "config_default_test.ini"])).
+    filename:join([?CONFIG_FIXTURESDIR, "config_default_test.ini"])
+).
 
 -define(CONFIG_FIXTURE_1,
-        filename:join([?CONFIG_FIXTURESDIR, "config_tests_1.ini"])).
+    filename:join([?CONFIG_FIXTURESDIR, "config_tests_1.ini"])
+).
 
 -define(CONFIG_FIXTURE_2,
-        filename:join([?CONFIG_FIXTURESDIR, "config_tests_2.ini"])).
+    filename:join([?CONFIG_FIXTURESDIR, "config_tests_2.ini"])
+).
 
 -define(CONFIG_DEFAULT_D,
-        filename:join([?CONFIG_FIXTURESDIR, "default.d"])).
+    filename:join([?CONFIG_FIXTURESDIR, "default.d"])
+).
 
 -define(CONFIG_LOCAL_D,
-        filename:join([?CONFIG_FIXTURESDIR, "local.d"])).
-
--define(CONFIG_FIXTURE_TEMP,
-    begin
-        FileName = filename:join([?TEMPDIR, "config_temp.ini"]),
-        {ok, Fd} = file:open(FileName, write),
-        ok = file:truncate(Fd),
-        ok = file:close(Fd),
-        FileName
-    end).
+    filename:join([?CONFIG_FIXTURESDIR, "local.d"])
+).
 
+-define(CONFIG_FIXTURE_TEMP, begin
+    FileName = filename:join([?TEMPDIR, "config_temp.ini"]),
+    {ok, Fd} = file:open(FileName, write),
+    ok = file:truncate(Fd),
+    ok = file:close(Fd),
+    FileName
+end).
 
 -define(T(F), {erlang:fun_to_list(F), F}).
 -define(FEXT(F), fun(_, _) -> F() end).
 
-
-
 setup() ->
     setup(?CONFIG_CHAIN).
 
 setup({temporary, Chain}) ->
     setup(Chain);
-
 setup({persistent, Chain}) ->
     setup(Chain ++ [?CONFIG_FIXTURE_TEMP]);
-
 setup(Chain) ->
     meck:new(couch_log),
     meck:expect(couch_log, error, fun(_, _) -> ok end),
@@ -77,11 +74,9 @@ setup(Chain) ->
     ok = application:set_env(config, ini_files, Chain),
     test_util:start_applications([config]).
 
-
 setup_empty() ->
     setup([]).
 
-
 setup_config_listener() ->
     Apps = setup(),
     Pid = spawn_config_listener(),
@@ -92,11 +87,9 @@ setup_config_notifier(Subscription) ->
     Pid = spawn_config_notifier(Subscription),
     {Apps, Pid}.
 
-
 teardown({Apps, Pid}) when is_pid(Pid) ->
     catch exit(Pid, kill),
     teardown(Apps);
-
 teardown(Apps) when is_list(Apps) ->
     meck:unload(),
     test_util:stop_applications(Apps).
@@ -107,27 +100,21 @@ teardown(_, {Apps, Pid}) when is_pid(Pid) ->
 teardown(_, Apps) ->
     teardown(Apps).
 
-
 handle_config_change("remove_handler", _Key, _Value, _Persist, {_Pid, _State}) ->
     remove_handler;
-
 handle_config_change("update_state", Key, Value, Persist, {Pid, State}) ->
     Pid ! {config_msg, {{"update_state", Key, Value, Persist}, State}},
     {ok, {Pid, Key}};
-
 handle_config_change("throw_error", _Key, _Value, _Persist, {_Pid, _State}) ->
     throw(this_is_an_error);
-
 handle_config_change(Section, Key, Value, Persist, {Pid, State}) ->
     Pid ! {config_msg, {{Section, Key, Value, Persist}, State}},
     {ok, {Pid, State}}.
 
-
 handle_config_terminate(Self, Reason, {Pid, State}) ->
     Pid ! {config_msg, {Self, Reason, State}},
     ok.
 
-
 config_get_test_() ->
     {
         "Config get tests",
@@ -147,7 +134,6 @@ config_get_test_() ->
         }
     }.
 
-
 config_set_test_() ->
     {
         "Config set tests",
@@ -163,7 +149,6 @@ config_set_test_() ->
         }
     }.
 
-
 config_del_test_() ->
     {
         "Config deletion tests",
@@ -178,7 +163,6 @@ config_del_test_() ->
         }
     }.
 
-
 config_features_test_() ->
     {
         "Config features tests",
@@ -194,8 +178,6 @@ config_features_test_() ->
         }
     }.
 
-
-
 config_override_test_() ->
     {
         "Configs overide tests",
@@ -204,27 +186,40 @@ config_override_test_() ->
             fun setup/1,
             fun teardown/2,
             [
-                {{temporary, [?CONFIG_DEFAULT_TEST]},
-                        fun should_ensure_in_defaults/2},
-                {{temporary, [?CONFIG_DEFAULT_TEST, ?CONFIG_FIXTURE_1]},
-                        fun should_override_options/2},
-                {{temporary, [?CONFIG_DEFAULT_TEST, ?CONFIG_FIXTURE_2]},
-                        fun should_create_new_sections_on_override/2},
-                {{temporary, [?CONFIG_DEFAULT_TEST, ?CONFIG_FIXTURE_1,
-                                ?CONFIG_FIXTURE_2]},
-                        fun should_win_last_in_chain/2},
-                {{temporary, [?CONFIG_DEFAULT_TEST, ?CONFIG_DEFAULT_D]},
-                        fun should_read_default_d/2},
-                {{temporary, [?CONFIG_DEFAULT_TEST, ?CONFIG_LOCAL_D]},
-                        fun should_read_local_d/2},
-                {{temporary, [?CONFIG_DEFAULT_TEST, ?CONFIG_DEFAULT_D,
-                                ?CONFIG_LOCAL_D]},
-                        fun should_read_default_and_local_d/2}
+                {{temporary, [?CONFIG_DEFAULT_TEST]}, fun should_ensure_in_defaults/2},
+                {
+                    {temporary, [?CONFIG_DEFAULT_TEST, ?CONFIG_FIXTURE_1]},
+                    fun should_override_options/2
+                },
+                {
+                    {temporary, [?CONFIG_DEFAULT_TEST, ?CONFIG_FIXTURE_2]},
+                    fun should_create_new_sections_on_override/2
+                },
+                {
+                    {temporary, [
+                        ?CONFIG_DEFAULT_TEST,
+                        ?CONFIG_FIXTURE_1,
+                        ?CONFIG_FIXTURE_2
+                    ]},
+                    fun should_win_last_in_chain/2
+                },
+                {
+                    {temporary, [?CONFIG_DEFAULT_TEST, ?CONFIG_DEFAULT_D]},
+                    fun should_read_default_d/2
+                },
+                {{temporary, [?CONFIG_DEFAULT_TEST, ?CONFIG_LOCAL_D]}, fun should_read_local_d/2},
+                {
+                    {temporary, [
+                        ?CONFIG_DEFAULT_TEST,
+                        ?CONFIG_DEFAULT_D,
+                        ?CONFIG_LOCAL_D
+                    ]},
+                    fun should_read_default_and_local_d/2
+                }
             ]
         }
     }.
 
-
 config_persistent_changes_test_() ->
     {
         "Config persistent changes",
@@ -233,17 +228,16 @@ config_persistent_changes_test_() ->
             fun setup/1,
             fun teardown/2,
             [
-                {{persistent, [?CONFIG_DEFAULT_TEST]},
-                        fun should_write_changes/2},
-                {{temporary, [?CONFIG_DEFAULT_TEST]},
-                        fun should_ensure_default_wasnt_modified/2},
-                {{temporary, [?CONFIG_FIXTURE_TEMP]},
-                        fun should_ensure_written_to_last_config_in_chain/2}
+                {{persistent, [?CONFIG_DEFAULT_TEST]}, fun should_write_changes/2},
+                {{temporary, [?CONFIG_DEFAULT_TEST]}, fun should_ensure_default_wasnt_modified/2},
+                {
+                    {temporary, [?CONFIG_FIXTURE_TEMP]},
+                    fun should_ensure_written_to_last_config_in_chain/2
+                }
             ]
         }
     }.
 
-
 config_no_files_test_() ->
     {
         "Test config with no files",
@@ -259,7 +253,6 @@ config_no_files_test_() ->
         }
     }.
 
-
 config_listener_behaviour_test_() ->
     {
         "Test config_listener behaviour",
@@ -303,7 +296,6 @@ config_notifier_behaviour_test_() ->
         }
     }.
 
-
 config_key_has_regex_test_() ->
     {
         "Test key with regex can be compiled and written to file",
@@ -317,7 +309,6 @@ config_key_has_regex_test_() ->
         }
     }.
 
-
 config_access_right_test_() ->
     {
         "Test config file access right",
@@ -334,90 +325,78 @@ config_access_right_test_() ->
         }
     }.
 
-
 should_write_config_to_file() ->
     ?assertEqual(ok, config:set("admins", "foo", "500", true)).
 
-
 should_handle_regex_patterns_in_key() ->
     ?assertEqual(ok, config:set("sect1", "pat||*", "true", true)),
     ?assertEqual([{"pat||*", "true"}], config:get("sect1")).
 
-
 should_delete_config_from_file() ->
     ?assertEqual(ok, config:delete("admins", "foo", true)).
 
-
 should_not_write_config_to_file() ->
     meck:new(config_writer),
     meck:expect(config_writer, save_to_file, fun(_, _) -> {error, eacces} end),
     ?assertEqual({error, eacces}, config:set("admins", "foo", "500", true)),
     meck:unload(config_writer).
 
-
 should_not_delete_config_from_file() ->
     meck:new(config_writer),
     meck:expect(config_writer, save_to_file, fun(_, _) -> {error, eacces} end),
     ?assertEqual({error, eacces}, config:delete("admins", "foo", true)),
     meck:unload(config_writer).
 
-
 should_load_all_configs() ->
     ?assert(length(config:all()) > 0).
 
-
 should_return_undefined_atom_on_missed_section() ->
     ?assertEqual(undefined, config:get("foo", "bar")).
 
-
 should_return_undefined_atom_on_missed_option() ->
     ?assertEqual(undefined, config:get("httpd", "foo")).
 
-
 should_return_custom_default_value_on_missed_option() ->
     ?assertEqual("bar", config:get("httpd", "foo", "bar")).
 
-
 should_only_return_default_on_missed_option() ->
     ?assertEqual("0", config:get("httpd", "port", "bar")).
 
-
 should_fail_to_get_binary_value() ->
     ?assertException(error, badarg, config:get(<<"a">>, <<"b">>, <<"c">>)).
 
-
 should_return_any_supported_default() ->
     Values = [undefined, "list", true, false, 0.1, 1],
-    lists:map(fun(V) ->
-        ?assertEqual(V, config:get(<<"foo">>, <<"bar">>, V))
-    end, Values).
-
+    lists:map(
+        fun(V) ->
+            ?assertEqual(V, config:get(<<"foo">>, <<"bar">>, V))
+        end,
+        Values
+    ).
 
 should_update_option() ->
     ok = config:set("mock_log", "level", "severe", false),
     ?assertEqual("severe", config:get("mock_log", "level")).
 
-
 should_create_new_section() ->
     ?assertEqual(undefined, config:get("new_section", "bizzle")),
     ?assertEqual(ok, config:set("new_section", "bizzle", "bang", false)),
     ?assertEqual("bang", config:get("new_section", "bizzle")).
 
-
 should_fail_to_set_binary_value() ->
-    ?assertException(error, badarg,
-            config:set(<<"a">>, <<"b">>, <<"c">>, false)).
-
+    ?assertException(
+        error,
+        badarg,
+        config:set(<<"a">>, <<"b">>, <<"c">>, false)
+    ).
 
 should_return_undefined_atom_after_option_deletion() ->
     ?assertEqual(ok, config:delete("mock_log", "level", false)),
     ?assertEqual(undefined, config:get("mock_log", "level")).
 
-
 should_be_ok_on_deleting_unknown_options() ->
     ?assertEqual(ok, config:delete("zoo", "boo", false)).
 
-
 should_ensure_in_defaults(_, _) ->
     ?_test(begin
         ?assertEqual("500", config:get("couchdb", "max_dbs_open")),
@@ -425,45 +404,38 @@ should_ensure_in_defaults(_, _) ->
         ?assertEqual(undefined, config:get("fizbang", "unicode"))
     end).
 
-
 should_override_options(_, _) ->
     ?_test(begin
         ?assertEqual("10", config:get("couchdb", "max_dbs_open")),
         ?assertEqual("4895", config:get("httpd", "port"))
     end).
 
-
 should_read_default_d(_, _) ->
     ?_test(begin
         ?assertEqual("11", config:get("couchdb", "max_dbs_open"))
     end).
 
-
 should_read_local_d(_, _) ->
     ?_test(begin
         ?assertEqual("12", config:get("couchdb", "max_dbs_open"))
     end).
 
-
 should_read_default_and_local_d(_, _) ->
     ?_test(begin
         ?assertEqual("12", config:get("couchdb", "max_dbs_open"))
     end).
 
-
 should_create_new_sections_on_override(_, _) ->
     ?_test(begin
         ?assertEqual("80", config:get("httpd", "port")),
         ?assertEqual("normalized", config:get("fizbang", "unicode"))
     end).
 
-
 should_win_last_in_chain(_, _) ->
     ?_test(begin
         ?assertEqual("80", config:get("httpd", "port"))
     end).
 
-
 should_write_changes(_, _) ->
     ?_test(begin
         ?assertEqual("5986", config:get("httpd", "port")),
@@ -473,46 +445,39 @@ should_write_changes(_, _) ->
         ?assertEqual(undefined, config:get("httpd", "bind_address"))
     end).
 
-
 should_ensure_default_wasnt_modified(_, _) ->
     ?_test(begin
         ?assertEqual("5986", config:get("httpd", "port")),
         ?assertEqual("127.0.0.1", config:get("httpd", "bind_address"))
     end).
 
-
 should_ensure_written_to_last_config_in_chain(_, _) ->
     ?_test(begin
         ?assertEqual("8080", config:get("httpd", "port")),
         ?assertEqual(undefined, config:get("httpd", "bind_address"))
     end).
 
-
 should_ensure_that_no_ini_files_loaded() ->
     ?assertEqual(0, length(config:all())).
 
-
 should_create_non_persistent_option() ->
     ?_test(begin
         ?assertEqual(ok, config:set("httpd", "port", "80", false)),
         ?assertEqual("80", config:get("httpd", "port"))
     end).
 
-
 should_create_persistent_option() ->
     ?_test(begin
         ?assertEqual(ok, config:set("httpd", "bind_address", "127.0.0.1")),
         ?assertEqual("127.0.0.1", config:get("httpd", "bind_address"))
     end).
 
-
 should_handle_value_change({_Apps, Pid}) ->
     ?_test(begin
         ?assertEqual(ok, config:set("httpd", "port", "80", false)),
         ?assertMatch({{"httpd", "port", "80", false}, _}, getmsg(Pid))
     end).
 
-
 should_pass_correct_state_to_handle_config_change({_Apps, Pid}) ->
     ?_test(begin
         ?assertEqual(ok, config:set("update_state", "foo", "any", false)),
@@ -521,7 +486,6 @@ should_pass_correct_state_to_handle_config_change({_Apps, Pid}) ->
         ?assertMatch({_, "foo"}, getmsg(Pid))
     end).
 
-
 should_pass_correct_state_to_handle_config_terminate({_Apps, Pid}) ->
     ?_test(begin
         ?assertEqual(ok, config:set("update_state", "foo", "any", false)),
@@ -532,27 +496,25 @@ should_pass_correct_state_to_handle_config_terminate({_Apps, Pid}) ->
         ?assertEqual({Pid, remove_handler, "foo"}, getmsg(Pid))
     end).
 
-
 should_pass_subscriber_pid_to_handle_config_terminate({_Apps, Pid}) ->
     ?_test(begin
         ?assertEqual(ok, config:set("remove_handler", "any", "any", false)),
         ?assertEqual({Pid, remove_handler, undefined}, getmsg(Pid))
     end).
 
-
 should_not_call_handle_config_after_related_process_death({_Apps, Pid}) ->
     ?_test(begin
         ?assertEqual(ok, config:set("remove_handler", "any", "any", false)),
         ?assertEqual({Pid, remove_handler, undefined}, getmsg(Pid)),
         ?assertEqual(ok, config:set("httpd", "port", "80", false)),
-        Event = receive
-            {config_msg, _} -> got_msg
+        Event =
+            receive
+                {config_msg, _} -> got_msg
             after 250 -> no_msg
-        end,
+            end,
         ?assertEqual(no_msg, Event)
     end).
 
-
 should_remove_handler_when_requested({_Apps, Pid}) ->
     ?_test(begin
         ?assertEqual(1, n_handlers()),
@@ -561,7 +523,6 @@ should_remove_handler_when_requested({_Apps, Pid}) ->
         ?assertEqual(0, n_handlers())
     end).
 
-
 should_remove_handler_when_pid_exits({_Apps, Pid}) ->
     ?_test(begin
         ?assertEqual(1, n_handlers()),
@@ -590,7 +551,6 @@ should_remove_handler_when_pid_exits({_Apps, Pid}) ->
         ?assertEqual(0, n_handlers())
     end).
 
-
 should_stop_monitor_on_error({_Apps, Pid}) ->
     ?_test(begin
         ?assertEqual(1, n_handlers()),
@@ -618,24 +578,33 @@ should_stop_monitor_on_error({_Apps, Pid}) ->
     end).
 
 should_notify(Subscription, {_Apps, Pid}) ->
-    {to_string(Subscription), ?_test(begin
-        ?assertEqual(ok, config:set("section_foo", "key_bar", "any", false)),
-        ?assertEqual({config_change,"section_foo", "key_bar", "any", false}, getmsg(Pid)),
-        ok
-    end)}.
+    {
+        to_string(Subscription),
+        ?_test(begin
+            ?assertEqual(ok, config:set("section_foo", "key_bar", "any", false)),
+            ?assertEqual({config_change, "section_foo", "key_bar", "any", false}, getmsg(Pid)),
+            ok
+        end)
+    }.
 
 should_not_notify([{Section, _}] = Subscription, {_Apps, Pid}) ->
-    {to_string(Subscription), ?_test(begin
-        ?assertEqual(ok, config:set(Section, "any", "any", false)),
-        ?assertError({timeout, config_msg}, getmsg(Pid)),
-        ok
-    end)};
+    {
+        to_string(Subscription),
+        ?_test(begin
+            ?assertEqual(ok, config:set(Section, "any", "any", false)),
+            ?assertError({timeout, config_msg}, getmsg(Pid)),
+            ok
+        end)
+    };
 should_not_notify(Subscription, {_Apps, Pid}) ->
-    {to_string(Subscription), ?_test(begin
-        ?assertEqual(ok, config:set("any", "any", "any", false)),
-        ?assertError({timeout, config_msg}, getmsg(Pid)),
-        ok
-    end)}.
+    {
+        to_string(Subscription),
+        ?_test(begin
+            ?assertEqual(ok, config:set("any", "any", "any", false)),
+            ?assertError({timeout, config_msg}, getmsg(Pid)),
+            ok
+        end)
+    }.
 
 should_unsubscribe_when_subscriber_gone(_Subscription, {_Apps, Pid}) ->
     ?_test(begin
@@ -663,7 +632,8 @@ should_unsubscribe_when_subscriber_gone(_Subscription, {_Apps, Pid}) ->
 
 should_not_add_duplicate(_, _) ->
     ?_test(begin
-        ?assertEqual(1, n_notifiers()), %% spawned from setup
+        %% spawned from setup
+        ?assertEqual(1, n_notifiers()),
 
         ?assertMatch(ok, config:subscribe_for_changes(all)),
 
@@ -675,7 +645,6 @@ should_not_add_duplicate(_, _) ->
         ok
     end).
 
-
 should_enable_features() ->
     [config:disable_feature(F) || F <- config:features()],
     ?assertEqual([], config:features()),
@@ -689,7 +658,6 @@ should_enable_features() ->
     ?assertEqual(ok, config:enable_feature(dogo)),
     ?assertEqual([dogo, snek], config:features()).
 
-
 should_disable_features() ->
     [config:disable_feature(F) || F <- config:features()],
     ?assertEqual([], config:features()),
@@ -713,25 +681,32 @@ should_keep_features_on_config_restart() ->
     ?assertEqual([snek], config:features()).
 
 should_notify_on_config_reload(Subscription, {_Apps, Pid}) ->
-    {to_string(Subscription), ?_test(begin
-        ?assertEqual(ok, config:set("section_foo", "key_bar", "any", true)),
-        ?assertEqual({config_change,"section_foo", "key_bar", "any", true}, getmsg(Pid)),
-        ?assertEqual(ok, config:set("section_foo", "key_bar", "not_any", false)),
-        ?assertEqual({config_change,"section_foo", "key_bar", "not_any", false}, getmsg(Pid)),
-        ?assertEqual(ok, config:reload()),
-        ?assertEqual({config_change,"section_foo", "key_bar", "any", true}, getmsg(Pid)),
-        ok
-    end)}.
+    {
+        to_string(Subscription),
+        ?_test(begin
+            ?assertEqual(ok, config:set("section_foo", "key_bar", "any", true)),
+            ?assertEqual({config_change, "section_foo", "key_bar", "any", true}, getmsg(Pid)),
+            ?assertEqual(ok, config:set("section_foo", "key_bar", "not_any", false)),
+            ?assertEqual({config_change, "section_foo", "key_bar", "not_any", false}, getmsg(Pid)),
+            ?assertEqual(ok, config:reload()),
+            ?assertEqual({config_change, "section_foo", "key_bar", "any", true}, getmsg(Pid)),
+            ok
+        end)
+    }.
 
 should_notify_on_config_reload_flush(Subscription, {_Apps, Pid}) ->
-    {to_string(Subscription), ?_test(begin
-        ?assertEqual(ok, config:set("section_foo_temp", "key_bar", "any", false)),
-        ?assertEqual({config_change,"section_foo_temp", "key_bar", "any", false}, getmsg(Pid)),
-        ?assertEqual(ok, config:reload()),
-        ?assertEqual({config_change,"section_foo_temp", "key_bar", deleted, true}, getmsg(Pid)),
-        ok
-    end)}.
-
+    {
+        to_string(Subscription),
+        ?_test(begin
+            ?assertEqual(ok, config:set("section_foo_temp", "key_bar", "any", false)),
+            ?assertEqual({config_change, "section_foo_temp", "key_bar", "any", false}, getmsg(Pid)),
+            ?assertEqual(ok, config:reload()),
+            ?assertEqual(
+                {config_change, "section_foo_temp", "key_bar", deleted, true}, getmsg(Pid)
+            ),
+            ok
+        end)
+    }.
 
 spawn_config_listener() ->
     Self = self(),
@@ -761,7 +736,6 @@ spawn_config_notifier(Subscription) ->
     end,
     Pid.
 
-
 loop(undefined) ->
     receive
         {config_msg, _} = Msg ->
@@ -773,7 +747,6 @@ loop(undefined) ->
         Msg ->
             erlang:error({invalid_message, Msg})
     end;
-
 loop({get_msg, From, Ref}) ->
     receive
         {config_msg, _} = Msg ->
@@ -784,7 +757,6 @@ loop({get_msg, From, Ref}) ->
             erlang:error({invalid_message, Msg})
     end,
     loop(undefined);
-
 loop({config_msg, _} = Msg) ->
     receive
         {get_msg, From, Ref} ->
@@ -794,7 +766,6 @@ loop({config_msg, _} = Msg) ->
     end,
     loop(undefined).
 
-
 getmsg(Pid) ->
     Ref = erlang:make_ref(),
     Pid ! {get_msg, self(), Ref},
@@ -804,7 +775,6 @@ getmsg(Pid) ->
         erlang:error({timeout, config_msg})
     end.
 
-
 n_handlers() ->
     Handlers = gen_event:which_handlers(config_event),
     length([Pid || {config_listener, {?MODULE, Pid}} <- Handlers]).
@@ -820,10 +790,12 @@ with_process_restart(Name) ->
     ok = stop_sync(whereis(Name), ?TIMEOUT),
     Now = now_us(),
     wait_process_restart(
-        Name, ?RESTART_TIMEOUT_IN_MILLISEC * 1000, 50, Now, Now).
+        Name, ?RESTART_TIMEOUT_IN_MILLISEC * 1000, 50, Now, Now
+    ).
 
-wait_process_restart(_Name, Timeout, _Delay, Started, Prev)
-        when Prev - Started > Timeout ->
+wait_process_restart(_Name, Timeout, _Delay, Started, Prev) when
+    Prev - Started > Timeout
+->
     timeout;
 wait_process_restart(Name, Timeout, Delay, Started, _Prev) ->
     case whereis(Name) of
@@ -841,8 +813,8 @@ stop_sync(Pid, Timeout) when is_pid(Pid) ->
             catch unlink(Pid),
             exit(Pid, kill),
             receive
-            {'DOWN', MRef, _, _, _} ->
-                ok
+                {'DOWN', MRef, _, _, _} ->
+                    ok
             after Timeout ->
                 timeout
             end
@@ -850,8 +822,8 @@ stop_sync(Pid, Timeout) when is_pid(Pid) ->
     after
         erlang:demonitor(MRef, [flush])
     end;
-stop_sync(_, _) -> error(badarg).
-
+stop_sync(_, _) ->
+    error(badarg).
 
 now_us() ->
     {MegaSecs, Secs, MicroSecs} = os:timestamp(),
