@@ -19,6 +19,8 @@
     delete/3,
     delete_compaction_files/3,
 
+    is_compacting/1,
+
     init/2,
     terminate/2,
     handle_db_updater_call/2,
@@ -80,12 +82,10 @@
     finish_compaction/4
 ]).
 
-
 -export([
     init_state/4
 ]).
 
-
 -export([
     id_tree_split/1,
     id_tree_join/2,
@@ -105,7 +105,6 @@
     purge_seq_tree_join/2
 ]).
 
-
 % Used by the compactor
 -export([
     update_header/2,
@@ -113,12 +112,10 @@
     copy_props/2
 ]).
 
-
 -include_lib("kernel/include/file.hrl").
 -include_lib("couch/include/couch_db.hrl").
 -include("couch_bt_engine.hrl").
 
-
 exists(FilePath) ->
     case is_file(FilePath) of
         true ->
@@ -127,7 +124,6 @@ exists(FilePath) ->
             is_file(FilePath ++ ".compact")
     end.
 
-
 delete(RootDir, FilePath, Async) ->
     %% Delete any leftover compaction files. If we don't do this a
     %% subsequent request for this DB will try to open them to use
@@ -137,70 +133,77 @@ delete(RootDir, FilePath, Async) ->
     % Delete the actual database file
     couch_file:delete(RootDir, FilePath, Async).
 
-
 delete_compaction_files(RootDir, FilePath, DelOpts) ->
-    lists:foreach(fun(Ext) ->
-        couch_file:delete(RootDir, FilePath ++ Ext, DelOpts)
-    end, [".compact", ".compact.data", ".compact.meta"]).
+    lists:foreach(
+        fun(Ext) ->
+            couch_file:delete(RootDir, FilePath ++ Ext, DelOpts)
+        end,
+        [".compact", ".compact.data", ".compact.meta"]
+    ).
 
+is_compacting([_ | _] = FilePath) ->
+    lists:any(
+        fun(Ext) ->
+            filelib:is_regular(FilePath ++ Ext)
+        end,
+        [".compact", ".compact.data", ".compact.meta"]
+    ).
 
 init(FilePath, Options) ->
     {ok, Fd} = open_db_file(FilePath, Options),
-    Header = case lists:member(create, Options) of
-        true ->
-            delete_compaction_files(FilePath),
-            Header0 = couch_bt_engine_header:new(),
-            Header1 = init_set_props(Fd, Header0, Options),
-            ok = couch_file:write_header(Fd, Header1),
-            Header1;
-        false ->
-            case couch_file:read_header(Fd) of
-                {ok, Header0} ->
-                    Header0;
-                no_valid_header ->
-                    delete_compaction_files(FilePath),
-                    Header0 =  couch_bt_engine_header:new(),
-                    ok = couch_file:write_header(Fd, Header0),
-                    Header0
-            end
-    end,
+    Header =
+        case lists:member(create, Options) of
+            true ->
+                delete_compaction_files(FilePath),
+                Header0 = couch_bt_engine_header:new(),
+                Header1 = init_set_props(Fd, Header0, Options),
+                ok = couch_file:write_header(Fd, Header1),
+                Header1;
+            false ->
+                case couch_file:read_header(Fd) of
+                    {ok, Header0} ->
+                        Header0;
+                    no_valid_header ->
+                        delete_compaction_files(FilePath),
+                        Header0 = couch_bt_engine_header:new(),
+                        ok = couch_file:write_header(Fd, Header0),
+                        Header0
+                end
+        end,
     {ok, init_state(FilePath, Fd, Header, Options)}.
 
-
 terminate(_Reason, St) ->
     % If the reason we died is because our fd disappeared
     % then we don't need to try closing it again.
     Ref = St#st.fd_monitor,
-    if Ref == closed -> ok; true ->
-        ok = couch_file:close(St#st.fd),
-        receive
-            {'DOWN', Ref, _,  _, _} ->
-                ok
+    if
+        Ref == closed ->
+            ok;
+        true ->
+            ok = couch_file:close(St#st.fd),
+            receive
+                {'DOWN', Ref, _, _, _} ->
+                    ok
             after 500 ->
                 ok
-        end
+            end
     end,
     couch_util:shutdown_sync(St#st.fd),
     ok.
 
-
 handle_db_updater_call(Msg, St) ->
     {stop, {invalid_call, Msg}, {invalid_call, Msg}, St}.
 
-
-handle_db_updater_info({'DOWN', Ref, _, _, _}, #st{fd_monitor=Ref} = St) ->
-    {stop, normal, St#st{fd=undefined, fd_monitor=closed}}.
-
+handle_db_updater_info({'DOWN', Ref, _, _, _}, #st{fd_monitor = Ref} = St) ->
+    {stop, normal, St#st{fd = undefined, fd_monitor = closed}}.
 
 incref(St) ->
     {ok, St#st{fd_monitor = erlang:monitor(process, St#st.fd)}}.
 
-
 decref(St) ->
     true = erlang:demonitor(St#st.fd_monitor, [flush]),
     ok.
 
-
 monitored_by(St) ->
     case erlang:process_info(St#st.fd, monitored_by) of
         {monitored_by, Pids} ->
@@ -209,33 +212,26 @@ monitored_by(St) ->
             []
     end.
 
-
 last_activity(#st{fd = Fd}) ->
     couch_file:last_read(Fd).
 
-
 get_compacted_seq(#st{header = Header}) ->
     couch_bt_engine_header:get(Header, compacted_seq).
 
-
 get_del_doc_count(#st{} = St) ->
     {ok, Reds} = couch_btree:full_reduce(St#st.id_tree),
     element(2, Reds).
 
-
 get_disk_version(#st{header = Header}) ->
     couch_bt_engine_header:get(Header, disk_version).
 
-
 get_doc_count(#st{} = St) ->
     {ok, Reds} = couch_btree:full_reduce(St#st.id_tree),
     element(1, Reds).
 
-
 get_epochs(#st{header = Header}) ->
     couch_bt_engine_header:get(Header, epochs).
 
-
 get_purge_seq(#st{purge_seq_tree = PurgeSeqTree}) ->
     Fun = fun({PurgeSeq, _, _, _}, _Reds, _Acc) ->
         {stop, PurgeSeq}
@@ -243,7 +239,6 @@ get_purge_seq(#st{purge_seq_tree = PurgeSeqTree}) ->
     {ok, _, PurgeSeq} = couch_btree:fold(PurgeSeqTree, Fun, 0, [{dir, rev}]),
     PurgeSeq.
 
-
 get_oldest_purge_seq(#st{purge_seq_tree = PurgeSeqTree}) ->
     Fun = fun({PurgeSeq, _, _, _}, _Reds, _Acc) ->
         {stop, PurgeSeq}
@@ -251,27 +246,25 @@ get_oldest_purge_seq(#st{purge_seq_tree = PurgeSeqTree}) ->
     {ok, _, PurgeSeq} = couch_btree:fold(PurgeSeqTree, Fun, 0, []),
     PurgeSeq.
 
-
 get_purge_infos_limit(#st{header = Header}) ->
     couch_bt_engine_header:get(Header, purge_infos_limit).
 
-
 get_revs_limit(#st{header = Header}) ->
     couch_bt_engine_header:get(Header, revs_limit).
 
-
 get_size_info(#st{} = St) ->
     {ok, FileSize} = couch_file:bytes(St#st.fd),
     {ok, DbReduction} = couch_btree:full_reduce(St#st.id_tree),
     SizeInfo0 = element(3, DbReduction),
-    SizeInfo = case SizeInfo0 of
-        SI when is_record(SI, size_info) ->
-            SI;
-        {AS, ES} ->
-            #size_info{active=AS, external=ES};
-        AS ->
-            #size_info{active=AS}
-    end,
+    SizeInfo =
+        case SizeInfo0 of
+            SI when is_record(SI, size_info) ->
+                SI;
+            {AS, ES} ->
+                #size_info{active = AS, external = ES};
+            AS ->
+                #size_info{active = AS}
+        end,
     ActiveSize = active_size(St, SizeInfo),
     ExternalSize = SizeInfo#size_info.external,
     [
@@ -280,7 +273,6 @@ get_size_info(#st{} = St) ->
         {file, FileSize}
     ].
 
-
 partition_size_cb(traverse, Key, {DC, DDC, Sizes}, {Partition, DCAcc, DDCAcc, SizesAcc}) ->
     case couch_partition:is_member(Key, Partition) of
         true ->
@@ -288,22 +280,18 @@ partition_size_cb(traverse, Key, {DC, DDC, Sizes}, {Partition, DCAcc, DDCAcc, Si
         false ->
             {ok, {Partition, DCAcc, DDCAcc, SizesAcc}}
     end;
-
 partition_size_cb(visit, FDI, _PrevReds, {Partition, DCAcc, DDCAcc, Acc}) ->
     InPartition = couch_partition:is_member(FDI#full_doc_info.id, Partition),
     Deleted = FDI#full_doc_info.deleted,
     case {InPartition, Deleted} of
         {true, true} ->
-            {ok, {Partition, DCAcc, DDCAcc + 1,
-                reduce_sizes(FDI#full_doc_info.sizes, Acc)}};
+            {ok, {Partition, DCAcc, DDCAcc + 1, reduce_sizes(FDI#full_doc_info.sizes, Acc)}};
         {true, false} ->
-            {ok, {Partition, DCAcc + 1, DDCAcc,
-                reduce_sizes(FDI#full_doc_info.sizes, Acc)}};
+            {ok, {Partition, DCAcc + 1, DDCAcc, reduce_sizes(FDI#full_doc_info.sizes, Acc)}};
         {false, _} ->
             {ok, {Partition, DCAcc, DDCAcc, Acc}}
     end.
 
-
 get_partition_info(#st{} = St, Partition) ->
     StartKey = couch_partition:start_key(Partition),
     EndKey = couch_partition:end_key(Partition),
@@ -322,7 +310,6 @@ get_partition_info(#st{} = St, Partition) ->
         ]}
     ].
 
-
 get_security(#st{header = Header} = St) ->
     case couch_bt_engine_header:get(Header, security_ptr) of
         undefined ->
@@ -332,7 +319,6 @@ get_security(#st{header = Header} = St) ->
             SecProps
     end.
 
-
 get_props(#st{header = Header} = St) ->
     case couch_bt_engine_header:get(Header, props_ptr) of
         undefined ->
@@ -342,15 +328,12 @@ get_props(#st{header = Header} = St) ->
             Props
     end.
 
-
 get_update_seq(#st{header = Header}) ->
     couch_bt_engine_header:get(Header, update_seq).
 
-
 get_uuid(#st{header = Header}) ->
     couch_bt_engine_header:get(Header, uuid).
 
-
 set_revs_limit(#st{header = Header} = St, RevsLimit) ->
     NewSt = St#st{
         header = couch_bt_engine_header:set(Header, [
@@ -360,7 +343,6 @@ set_revs_limit(#st{header = Header} = St, RevsLimit) ->
     },
     {ok, increment_update_seq(NewSt)}.
 
-
 set_purge_infos_limit(#st{header = Header} = St, PurgeInfosLimit) ->
     NewSt = St#st{
         header = couch_bt_engine_header:set(Header, [
@@ -370,7 +352,6 @@ set_purge_infos_limit(#st{header = Header} = St, PurgeInfosLimit) ->
     },
     {ok, increment_update_seq(NewSt)}.
 
-
 set_security(#st{header = Header} = St, NewSecurity) ->
     Options = [{compression, St#st.compression}],
     {ok, Ptr, _} = couch_file:append_term(St#st.fd, NewSecurity, Options),
@@ -382,7 +363,6 @@ set_security(#st{header = Header} = St, NewSecurity) ->
     },
     {ok, increment_update_seq(NewSt)}.
 
-
 set_props(#st{header = Header} = St, Props) ->
     Options = [{compression, St#st.compression}],
     {ok, Ptr, _} = couch_file:append_term(St#st.fd, Props, Options),
@@ -394,22 +374,25 @@ set_props(#st{header = Header} = St, Props) ->
     },
     {ok, increment_update_seq(NewSt)}.
 
-
 open_docs(#st{} = St, DocIds) ->
     Results = couch_btree:lookup(St#st.id_tree, DocIds),
-    lists:map(fun
-        ({ok, FDI}) -> FDI;
-        (not_found) -> not_found
-    end, Results).
-
+    lists:map(
+        fun
+            ({ok, FDI}) -> FDI;
+            (not_found) -> not_found
+        end,
+        Results
+    ).
 
 open_local_docs(#st{} = St, DocIds) ->
     Results = couch_btree:lookup(St#st.local_tree, DocIds),
-    lists:map(fun
-        ({ok, Doc}) -> Doc;
-        (not_found) -> not_found
-    end, Results).
-
+    lists:map(
+        fun
+            ({ok, Doc}) -> Doc;
+            (not_found) -> not_found
+        end,
+        Results
+    ).
 
 read_doc_body(#st{} = St, #doc{} = Doc) ->
     {ok, {Body, Atts}} = couch_file:pread_term(St#st.fd, Doc#doc.body),
@@ -418,14 +401,15 @@ read_doc_body(#st{} = St, #doc{} = Doc) ->
         atts = Atts
     }.
 
-
 load_purge_infos(St, UUIDs) ->
     Results = couch_btree:lookup(St#st.purge_tree, UUIDs),
-    lists:map(fun
-        ({ok, Info}) -> Info;
-        (not_found) -> not_found
-    end, Results).
-
+    lists:map(
+        fun
+            ({ok, Info}) -> Info;
+            (not_found) -> not_found
+        end,
+        Results
+    ).
 
 serialize_doc(#st{} = St, #doc{} = Doc) ->
     Compress = fun(Term) ->
@@ -449,7 +433,6 @@ serialize_doc(#st{} = St, #doc{} = Doc) ->
         meta = [{comp_body, Body} | Doc#doc.meta]
     }.
 
-
 write_doc_body(St, #doc{} = Doc) ->
     #st{
         fd = Fd
@@ -457,46 +440,57 @@ write_doc_body(St, #doc{} = Doc) ->
     {ok, Ptr, Written} = couch_file:append_raw_chunk(Fd, Doc#doc.body),
     {ok, Doc#doc{body = Ptr}, Written}.
 
-
 write_doc_infos(#st{} = St, Pairs, LocalDocs) ->
     #st{
         id_tree = IdTree,
         seq_tree = SeqTree,
         local_tree = LocalTree
     } = St,
-    FinalAcc = lists:foldl(fun({OldFDI, NewFDI}, Acc) ->
-        {AddAcc, RemIdsAcc, RemSeqsAcc} = Acc,
-        case {OldFDI, NewFDI} of
-            {not_found, #full_doc_info{}} ->
-                {[NewFDI | AddAcc], RemIdsAcc, RemSeqsAcc};
-            {#full_doc_info{id = Id}, #full_doc_info{id = Id}} ->
-                NewAddAcc = [NewFDI | AddAcc],
-                NewRemSeqsAcc = [OldFDI#full_doc_info.update_seq | RemSeqsAcc],
-                {NewAddAcc, RemIdsAcc, NewRemSeqsAcc};
-            {#full_doc_info{id = Id}, not_found} ->
-                NewRemIdsAcc = [Id | RemIdsAcc],
-                NewRemSeqsAcc = [OldFDI#full_doc_info.update_seq | RemSeqsAcc],
-                {AddAcc, NewRemIdsAcc, NewRemSeqsAcc}
-        end
-    end, {[], [], []}, Pairs),
+    FinalAcc = lists:foldl(
+        fun({OldFDI, NewFDI}, Acc) ->
+            {AddAcc, RemIdsAcc, RemSeqsAcc} = Acc,
+            case {OldFDI, NewFDI} of
+                {not_found, #full_doc_info{}} ->
+                    {[NewFDI | AddAcc], RemIdsAcc, RemSeqsAcc};
+                {#full_doc_info{id = Id}, #full_doc_info{id = Id}} ->
+                    NewAddAcc = [NewFDI | AddAcc],
+                    NewRemSeqsAcc = [OldFDI#full_doc_info.update_seq | RemSeqsAcc],
+                    {NewAddAcc, RemIdsAcc, NewRemSeqsAcc};
+                {#full_doc_info{id = Id}, not_found} ->
+                    NewRemIdsAcc = [Id | RemIdsAcc],
+                    NewRemSeqsAcc = [OldFDI#full_doc_info.update_seq | RemSeqsAcc],
+                    {AddAcc, NewRemIdsAcc, NewRemSeqsAcc}
+            end
+        end,
+        {[], [], []},
+        Pairs
+    ),
 
     {Add, RemIds, RemSeqs} = FinalAcc,
     {ok, IdTree2} = couch_btree:add_remove(IdTree, Add, RemIds),
     {ok, SeqTree2} = couch_btree:add_remove(SeqTree, Add, RemSeqs),
 
-    {AddLDocs, RemLDocIds} = lists:foldl(fun(Doc, {AddAcc, RemAcc}) ->
-        case Doc#doc.deleted of
-            true ->
-                {AddAcc, [Doc#doc.id | RemAcc]};
-            false ->
-                {[Doc | AddAcc], RemAcc}
-        end
-    end, {[], []}, LocalDocs),
+    {AddLDocs, RemLDocIds} = lists:foldl(
+        fun(Doc, {AddAcc, RemAcc}) ->
+            case Doc#doc.deleted of
+                true ->
+                    {AddAcc, [Doc#doc.id | RemAcc]};
+                false ->
+                    {[Doc | AddAcc], RemAcc}
+            end
+        end,
+        {[], []},
+        LocalDocs
+    ),
     {ok, LocalTree2} = couch_btree:add_remove(LocalTree, AddLDocs, RemLDocIds),
 
-    NewUpdateSeq = lists:foldl(fun(#full_doc_info{update_seq=Seq}, Acc) ->
-        erlang:max(Seq, Acc)
-    end, get_update_seq(St), Add),
+    NewUpdateSeq = lists:foldl(
+        fun(#full_doc_info{update_seq = Seq}, Acc) ->
+            erlang:max(Seq, Acc)
+        end,
+        get_update_seq(St),
+        Add
+    ),
 
     NewHeader = couch_bt_engine_header:set(St#st.header, [
         {update_seq, NewUpdateSeq}
@@ -510,7 +504,6 @@ write_doc_infos(#st{} = St, Pairs, LocalDocs) ->
         needs_commit = true
     }}.
 
-
 purge_docs(#st{} = St, Pairs, PurgeInfos) ->
     #st{
         id_tree = IdTree,
@@ -529,10 +522,11 @@ purge_docs(#st{} = St, Pairs, PurgeInfos) ->
     % We bump NewUpdateSeq because we have to ensure that
     % indexers see that they need to process the new purge
     % information.
-    UpdateSeq = case NewSeq == CurrSeq of
-        true -> CurrSeq + 1;
-        false -> NewSeq
-    end,
+    UpdateSeq =
+        case NewSeq == CurrSeq of
+            true -> CurrSeq + 1;
+            false -> NewSeq
+        end,
     Header = couch_bt_engine_header:set(St#st.header, [
         {update_seq, UpdateSeq}
     ]),
@@ -550,7 +544,6 @@ purge_docs(#st{} = St, Pairs, PurgeInfos) ->
         needs_commit = true
     }}.
 
-
 copy_purge_infos(#st{} = St, PurgeInfos) ->
     #st{
         purge_tree = PurgeTree,
@@ -559,12 +552,11 @@ copy_purge_infos(#st{} = St, PurgeInfos) ->
     {ok, PurgeTree2} = couch_btree:add(PurgeTree, PurgeInfos),
     {ok, PurgeSeqTree2} = couch_btree:add(PurgeSeqTree, PurgeInfos),
     {ok, St#st{
-       purge_tree = PurgeTree2,
-       purge_seq_tree = PurgeSeqTree2,
-       needs_commit = true
+        purge_tree = PurgeTree2,
+        purge_seq_tree = PurgeSeqTree2,
+        needs_commit = true
     }}.
 
-
 commit_data(St) ->
     #st{
         fd = Fd,
@@ -587,32 +579,26 @@ commit_data(St) ->
             {ok, St}
     end.
 
-
 open_write_stream(#st{} = St, Options) ->
     couch_stream:open({couch_bt_engine_stream, {St#st.fd, []}}, Options).
 
-
 open_read_stream(#st{} = St, StreamSt) ->
     {ok, {couch_bt_engine_stream, {St#st.fd, StreamSt}}}.
 
-
 is_active_stream(#st{} = St, {couch_bt_engine_stream, {Fd, _}}) ->
     St#st.fd == Fd;
 is_active_stream(_, _) ->
     false.
 
-
 fold_docs(St, UserFun, UserAcc, Options) ->
     fold_docs_int(St, St#st.id_tree, UserFun, UserAcc, Options).
 
-
 fold_local_docs(St, UserFun, UserAcc, Options) ->
     case fold_docs_int(St, St#st.local_tree, UserFun, UserAcc, Options) of
         {ok, _Reds, FinalAcc} -> {ok, null, FinalAcc};
         {ok, FinalAcc} -> {ok, FinalAcc}
     end.
 
-
 fold_changes(St, SinceSeq, UserFun, UserAcc, Options) ->
     Fun = fun drop_reductions/4,
     InAcc = {UserFun, UserAcc},
@@ -621,13 +607,13 @@ fold_changes(St, SinceSeq, UserFun, UserAcc, Options) ->
     {_, FinalUserAcc} = OutAcc,
     {ok, FinalUserAcc}.
 
-
 fold_purge_infos(St, StartSeq0, UserFun, UserAcc, Options) ->
     PurgeSeqTree = St#st.purge_seq_tree,
     StartSeq = StartSeq0 + 1,
     MinSeq = get_oldest_purge_seq(St),
-    if MinSeq =< StartSeq -> ok; true ->
-        erlang:error({invalid_start_purge_seq, StartSeq0})
+    if
+        MinSeq =< StartSeq -> ok;
+        true -> erlang:error({invalid_start_purge_seq, StartSeq0})
     end,
     Wrapper = fun(Info, _Reds, UAcc) ->
         UserFun(Info, UAcc)
@@ -636,7 +622,6 @@ fold_purge_infos(St, StartSeq0, UserFun, UserAcc, Options) ->
     {ok, _, OutAcc} = couch_btree:fold(PurgeSeqTree, Wrapper, UserAcc, Opts),
     {ok, OutAcc}.
 
-
 count_changes_since(St, SinceSeq) ->
     BTree = St#st.seq_tree,
     FoldFun = fun(_SeqStart, PartialReds, 0) ->
@@ -646,13 +631,11 @@ count_changes_since(St, SinceSeq) ->
     {ok, Changes} = couch_btree:fold_reduce(BTree, FoldFun, 0, Opts),
     Changes.
 
-
 start_compaction(St, DbName, Options, Parent) ->
     Args = [St, DbName, Options, Parent],
     Pid = spawn_link(couch_bt_engine_compactor, start, Args),
     {ok, St, Pid}.
 
-
 finish_compaction(OldState, DbName, Options, CompactFilePath) ->
     {ok, NewState1} = ?MODULE:init(CompactFilePath, Options),
     OldSeq = get_update_seq(OldState),
@@ -661,15 +644,21 @@ finish_compaction(OldState, DbName, Options, CompactFilePath) ->
         true ->
             finish_compaction_int(OldState, NewState1);
         false ->
-            couch_log:info("Compaction file still behind main file "
-                           "(update seq=~p. compact update seq=~p). Retrying.",
-                           [OldSeq, NewSeq]),
+            Level = list_to_existing_atom(
+                config:get(
+                    "couchdb", "compaction_log_level", "info"
+                )
+            ),
+            couch_log:Level(
+                "Compaction file still behind main file "
+                "(update seq=~p. compact update seq=~p). Retrying.",
+                [OldSeq, NewSeq]
+            ),
             ok = decref(NewState1),
             start_compaction(OldState, DbName, Options, self())
     end.
 
-
-id_tree_split(#full_doc_info{}=Info) ->
+id_tree_split(#full_doc_info{} = Info) ->
     #full_doc_info{
         id = Id,
         update_seq = Seq,
@@ -679,11 +668,9 @@ id_tree_split(#full_doc_info{}=Info) ->
     } = Info,
     {Id, {Seq, ?b2i(Deleted), split_sizes(SizeInfo), disk_tree(Tree)}}.
 
-
 id_tree_join(Id, {HighSeq, Deleted, DiskTree}) ->
     % Handle old formats before data_size was added
     id_tree_join(Id, {HighSeq, Deleted, #size_info{}, DiskTree});
-
 id_tree_join(Id, {HighSeq, Deleted, Sizes, DiskTree}) ->
     #full_doc_info{
         id = Id,
@@ -693,29 +680,35 @@ id_tree_join(Id, {HighSeq, Deleted, Sizes, DiskTree}) ->
         rev_tree = rev_tree(DiskTree)
     }.
 
-
 id_tree_reduce(reduce, FullDocInfos) ->
-    lists:foldl(fun(Info, {NotDeleted, Deleted, Sizes}) ->
-        Sizes2 = reduce_sizes(Sizes, Info#full_doc_info.sizes),
-        case Info#full_doc_info.deleted of
-        true ->
-            {NotDeleted, Deleted + 1, Sizes2};
-        false ->
-            {NotDeleted + 1, Deleted, Sizes2}
-        end
-    end, {0, 0, #size_info{}}, FullDocInfos);
+    lists:foldl(
+        fun(Info, {NotDeleted, Deleted, Sizes}) ->
+            Sizes2 = reduce_sizes(Sizes, Info#full_doc_info.sizes),
+            case Info#full_doc_info.deleted of
+                true ->
+                    {NotDeleted, Deleted + 1, Sizes2};
+                false ->
+                    {NotDeleted + 1, Deleted, Sizes2}
+            end
+        end,
+        {0, 0, #size_info{}},
+        FullDocInfos
+    );
 id_tree_reduce(rereduce, Reds) ->
-    lists:foldl(fun
-        ({NotDeleted, Deleted}, {AccNotDeleted, AccDeleted, _AccSizes}) ->
-            % pre 1.2 format, will be upgraded on compaction
-            {AccNotDeleted + NotDeleted, AccDeleted + Deleted, nil};
-        ({NotDeleted, Deleted, Sizes}, {AccNotDeleted, AccDeleted, AccSizes}) ->
-            AccSizes2 = reduce_sizes(AccSizes, Sizes),
-            {AccNotDeleted + NotDeleted, AccDeleted + Deleted, AccSizes2}
-    end, {0, 0, #size_info{}}, Reds).
+    lists:foldl(
+        fun
+            ({NotDeleted, Deleted}, {AccNotDeleted, AccDeleted, _AccSizes}) ->
+                % pre 1.2 format, will be upgraded on compaction
+                {AccNotDeleted + NotDeleted, AccDeleted + Deleted, nil};
+            ({NotDeleted, Deleted, Sizes}, {AccNotDeleted, AccDeleted, AccSizes}) ->
+                AccSizes2 = reduce_sizes(AccSizes, Sizes),
+                {AccNotDeleted + NotDeleted, AccDeleted + Deleted, AccSizes2}
+        end,
+        {0, 0, #size_info{}},
+        Reds
+    ).
 
-
-seq_tree_split(#full_doc_info{}=Info) ->
+seq_tree_split(#full_doc_info{} = Info) ->
     #full_doc_info{
         id = Id,
         update_seq = Seq,
@@ -725,10 +718,8 @@ seq_tree_split(#full_doc_info{}=Info) ->
     } = Info,
     {Seq, {Id, ?b2i(Del), split_sizes(SizeInfo), disk_tree(Tree)}}.
 
-
 seq_tree_join(Seq, {Id, Del, DiskTree}) when is_integer(Del) ->
     seq_tree_join(Seq, {Id, Del, {0, 0}, DiskTree});
-
 seq_tree_join(Seq, {Id, Del, Sizes, DiskTree}) when is_integer(Del) ->
     #full_doc_info{
         id = Id,
@@ -737,37 +728,39 @@ seq_tree_join(Seq, {Id, Del, Sizes, DiskTree}) when is_integer(Del) ->
         sizes = join_sizes(Sizes),
         rev_tree = rev_tree(DiskTree)
     };
-
 seq_tree_join(KeySeq, {Id, RevInfos, DeletedRevInfos}) ->
     % Older versions stored #doc_info records in the seq_tree.
     % Compact to upgrade.
-    Revs = lists:map(fun({Rev, Seq, Bp}) ->
-        #rev_info{rev = Rev, seq = Seq, deleted = false, body_sp = Bp}
-    end, RevInfos),
-    DeletedRevs = lists:map(fun({Rev, Seq, Bp}) ->
-        #rev_info{rev = Rev, seq = Seq, deleted = true, body_sp = Bp}
-    end, DeletedRevInfos),
+    Revs = lists:map(
+        fun({Rev, Seq, Bp}) ->
+            #rev_info{rev = Rev, seq = Seq, deleted = false, body_sp = Bp}
+        end,
+        RevInfos
+    ),
+    DeletedRevs = lists:map(
+        fun({Rev, Seq, Bp}) ->
+            #rev_info{rev = Rev, seq = Seq, deleted = true, body_sp = Bp}
+        end,
+        DeletedRevInfos
+    ),
     #doc_info{
         id = Id,
         high_seq = KeySeq,
         revs = Revs ++ DeletedRevs
     }.
 
-
 seq_tree_reduce(reduce, DocInfos) ->
     % count the number of documents
     length(DocInfos);
 seq_tree_reduce(rereduce, Reds) ->
     lists:sum(Reds).
 
-
 local_tree_split(#doc{revs = {0, [Rev]}} = Doc) when is_binary(Rev) ->
     #doc{
         id = Id,
         body = BodyData
     } = Doc,
     {Id, {binary_to_integer(Rev), BodyData}};
-
 local_tree_split(#doc{revs = {0, [Rev]}} = Doc) when is_integer(Rev) ->
     #doc{
         id = Id,
@@ -775,14 +768,12 @@ local_tree_split(#doc{revs = {0, [Rev]}} = Doc) when is_integer(Rev) ->
     } = Doc,
     {Id, {Rev, BodyData}}.
 
-
 local_tree_join(Id, {Rev, BodyData}) when is_binary(Rev) ->
     #doc{
         id = Id,
         revs = {0, [Rev]},
         body = BodyData
     };
-
 local_tree_join(Id, {Rev, BodyData}) when is_integer(Rev) ->
     #doc{
         id = Id,
@@ -790,30 +781,24 @@ local_tree_join(Id, {Rev, BodyData}) when is_integer(Rev) ->
         body = BodyData
     }.
 
-
 purge_tree_split({PurgeSeq, UUID, DocId, Revs}) ->
     {UUID, {PurgeSeq, DocId, Revs}}.
 
-
 purge_tree_join(UUID, {PurgeSeq, DocId, Revs}) ->
     {PurgeSeq, UUID, DocId, Revs}.
 
-
 purge_seq_tree_split({PurgeSeq, UUID, DocId, Revs}) ->
     {PurgeSeq, {UUID, DocId, Revs}}.
 
-
 purge_seq_tree_join(PurgeSeq, {UUID, DocId, Revs}) ->
     {PurgeSeq, UUID, DocId, Revs}.
 
-
 purge_tree_reduce(reduce, IdRevs) ->
     % count the number of purge requests
     length(IdRevs);
 purge_tree_reduce(rereduce, Reds) ->
     lists:sum(Reds).
 
-
 set_update_seq(#st{header = Header} = St, UpdateSeq) ->
     {ok, St#st{
         header = couch_bt_engine_header:set(Header, [
@@ -822,7 +807,6 @@ set_update_seq(#st{header = Header} = St, UpdateSeq) ->
         needs_commit = true
     }}.
 
-
 copy_security(#st{header = Header} = St, SecProps) ->
     Options = [{compression, St#st.compression}],
     {ok, Ptr, _} = couch_file:append_term(St#st.fd, SecProps, Options),
@@ -833,7 +817,6 @@ copy_security(#st{header = Header} = St, SecProps) ->
         needs_commit = true
     }}.
 
-
 copy_props(#st{header = Header} = St, Props) ->
     Options = [{compression, St#st.compression}],
     {ok, Ptr, _} = couch_file:append_term(St#st.fd, Props, Options),
@@ -844,7 +827,6 @@ copy_props(#st{header = Header} = St, Props) ->
         needs_commit = true
     }}.
 
-
 open_db_file(FilePath, Options) ->
     case couch_file:open(FilePath, Options) of
         {ok, Fd} ->
@@ -866,7 +848,6 @@ open_db_file(FilePath, Options) ->
             throw(Error)
     end.
 
-
 init_state(FilePath, Fd, Header0, Options) ->
     ok = couch_file:sync(Fd),
 
@@ -878,26 +859,26 @@ init_state(FilePath, Fd, Header0, Options) ->
 
     IdTreeState = couch_bt_engine_header:id_tree_state(Header),
     {ok, IdTree} = couch_btree:open(IdTreeState, Fd, [
-            {split, fun ?MODULE:id_tree_split/1},
-            {join, fun ?MODULE:id_tree_join/2},
-            {reduce, fun ?MODULE:id_tree_reduce/2},
-            {compression, Compression}
-        ]),
+        {split, fun ?MODULE:id_tree_split/1},
+        {join, fun ?MODULE:id_tree_join/2},
+        {reduce, fun ?MODULE:id_tree_reduce/2},
+        {compression, Compression}
+    ]),
 
     SeqTreeState = couch_bt_engine_header:seq_tree_state(Header),
     {ok, SeqTree} = couch_btree:open(SeqTreeState, Fd, [
-            {split, fun ?MODULE:seq_tree_split/1},
-            {join, fun ?MODULE:seq_tree_join/2},
-            {reduce, fun ?MODULE:seq_tree_reduce/2},
-            {compression, Compression}
-        ]),
+        {split, fun ?MODULE:seq_tree_split/1},
+        {join, fun ?MODULE:seq_tree_join/2},
+        {reduce, fun ?MODULE:seq_tree_reduce/2},
+        {compression, Compression}
+    ]),
 
     LocalTreeState = couch_bt_engine_header:local_tree_state(Header),
     {ok, LocalTree} = couch_btree:open(LocalTreeState, Fd, [
-            {split, fun ?MODULE:local_tree_split/1},
-            {join, fun ?MODULE:local_tree_join/2},
-            {compression, Compression}
-        ]),
+        {split, fun ?MODULE:local_tree_split/1},
+        {join, fun ?MODULE:local_tree_join/2},
+        {compression, Compression}
+    ]),
 
     PurgeTreeState = couch_bt_engine_header:purge_tree_state(Header),
     {ok, PurgeTree} = couch_btree:open(PurgeTreeState, Fd, [
@@ -940,7 +921,6 @@ init_state(FilePath, Fd, Header0, Options) ->
             St
     end.
 
-
 update_header(St, Header) ->
     couch_bt_engine_header:set(Header, [
         {seq_tree_state, couch_btree:get_state(St#st.seq_tree)},
@@ -950,7 +930,6 @@ update_header(St, Header) ->
         {purge_seq_tree_state, couch_btree:get_state(St#st.purge_seq_tree)}
     ]).
 
-
 increment_update_seq(#st{header = Header} = St) ->
     UpdateSeq = couch_bt_engine_header:get(Header, update_seq),
     St#st{
@@ -959,7 +938,6 @@ increment_update_seq(#st{header = Header} = St) ->
         ])
     }.
 
-
 set_default_security_object(Fd, Header, Compression, Options) ->
     case couch_bt_engine_header:get(Header, security_ptr) of
         Pointer when is_integer(Pointer) ->
@@ -971,7 +949,6 @@ set_default_security_object(Fd, Header, Compression, Options) ->
             couch_bt_engine_header:set(Header, security_ptr, Ptr)
     end.
 
-
 % This function is here, and not in couch_bt_engine_header
 % because it requires modifying file contents
 upgrade_purge_info(Fd, Header) ->
@@ -980,24 +957,32 @@ upgrade_purge_info(Fd, Header) ->
             Header;
         Ptr when is_tuple(Ptr) ->
             Header;
-        PurgeSeq when is_integer(PurgeSeq)->
+        PurgeSeq when is_integer(PurgeSeq) ->
             % Pointer to old purged ids/revs is in purge_seq_tree_state
             Ptr = couch_bt_engine_header:get(Header, purge_seq_tree_state),
 
             case Ptr of
                 nil ->
                     PTS = couch_bt_engine_header:purge_tree_state(Header),
-                    PurgeTreeSt = case PTS of 0 -> nil; Else -> Else end,
+                    PurgeTreeSt =
+                        case PTS of
+                            0 -> nil;
+                            Else -> Else
+                        end,
                     couch_bt_engine_header:set(Header, [
                         {purge_tree_state, PurgeTreeSt}
                     ]);
                 _ ->
                     {ok, PurgedIdsRevs} = couch_file:pread_term(Fd, Ptr),
 
-                    {Infos, _} = lists:foldl(fun({Id, Revs}, {InfoAcc, PSeq}) ->
-                        Info = {PSeq, couch_uuids:random(), Id, Revs},
-                        {[Info | InfoAcc], PSeq + 1}
-                    end, {[], PurgeSeq}, PurgedIdsRevs),
+                    {Infos, _} = lists:foldl(
+                        fun({Id, Revs}, {InfoAcc, PSeq}) ->
+                            Info = {PSeq, couch_uuids:random(), Id, Revs},
+                            {[Info | InfoAcc], PSeq + 1}
+                        end,
+                        {[], PurgeSeq},
+                        PurgedIdsRevs
+                    ),
 
                     {ok, PurgeTree} = couch_btree:open(nil, Fd, [
                         {split, fun ?MODULE:purge_tree_split/1},
@@ -1022,7 +1007,6 @@ upgrade_purge_info(Fd, Header) ->
             end
     end.
 
-
 init_set_props(Fd, Header, Options) ->
     case couch_util:get_value(props, Options) of
         undefined ->
@@ -1034,70 +1018,70 @@ init_set_props(Fd, Header, Options) ->
             couch_bt_engine_header:set(Header, props_ptr, Ptr)
     end.
 
-
 delete_compaction_files(FilePath) ->
     RootDir = config:get("couchdb", "database_dir", "."),
     DelOpts = [{context, compaction}],
     delete_compaction_files(RootDir, FilePath, DelOpts).
 
-
 rev_tree(DiskTree) ->
-    couch_key_tree:map(fun
-        (_RevId, {Del, Ptr, Seq}) ->
-            #leaf{
-                deleted = ?i2b(Del),
-                ptr = Ptr,
-                seq = Seq
-            };
-        (_RevId, {Del, Ptr, Seq, Size}) ->
-            #leaf{
-                deleted = ?i2b(Del),
-                ptr = Ptr,
-                seq = Seq,
-                sizes = couch_db_updater:upgrade_sizes(Size)
-            };
-        (_RevId, {Del, Ptr, Seq, Sizes, Atts}) ->
-            #leaf{
-                deleted = ?i2b(Del),
-                ptr = Ptr,
-                seq = Seq,
-                sizes = couch_db_updater:upgrade_sizes(Sizes),
-                atts = Atts
-            };
-        (_RevId, ?REV_MISSING) ->
-            ?REV_MISSING
-    end, DiskTree).
-
+    couch_key_tree:map(
+        fun
+            (_RevId, {Del, Ptr, Seq}) ->
+                #leaf{
+                    deleted = ?i2b(Del),
+                    ptr = Ptr,
+                    seq = Seq
+                };
+            (_RevId, {Del, Ptr, Seq, Size}) ->
+                #leaf{
+                    deleted = ?i2b(Del),
+                    ptr = Ptr,
+                    seq = Seq,
+                    sizes = couch_db_updater:upgrade_sizes(Size)
+                };
+            (_RevId, {Del, Ptr, Seq, Sizes, Atts}) ->
+                #leaf{
+                    deleted = ?i2b(Del),
+                    ptr = Ptr,
+                    seq = Seq,
+                    sizes = couch_db_updater:upgrade_sizes(Sizes),
+                    atts = Atts
+                };
+            (_RevId, ?REV_MISSING) ->
+                ?REV_MISSING
+        end,
+        DiskTree
+    ).
 
 disk_tree(RevTree) ->
-    couch_key_tree:map(fun
-        (_RevId, ?REV_MISSING) ->
-            ?REV_MISSING;
-        (_RevId, #leaf{} = Leaf) ->
-            #leaf{
-                deleted = Del,
-                ptr = Ptr,
-                seq = Seq,
-                sizes = Sizes,
-                atts = Atts
-            } = Leaf,
-            {?b2i(Del), Ptr, Seq, split_sizes(Sizes), Atts}
-    end, RevTree).
+    couch_key_tree:map(
+        fun
+            (_RevId, ?REV_MISSING) ->
+                ?REV_MISSING;
+            (_RevId, #leaf{} = Leaf) ->
+                #leaf{
+                    deleted = Del,
+                    ptr = Ptr,
+                    seq = Seq,
+                    sizes = Sizes,
+                    atts = Atts
+                } = Leaf,
+                {?b2i(Del), Ptr, Seq, split_sizes(Sizes), Atts}
+        end,
+        RevTree
+    ).
 
-
-split_sizes(#size_info{}=SI) ->
+split_sizes(#size_info{} = SI) ->
     {SI#size_info.active, SI#size_info.external}.
 
-
 join_sizes({Active, External}) when is_integer(Active), is_integer(External) ->
-    #size_info{active=Active, external=External}.
-
+    #size_info{active = Active, external = External}.
 
 reduce_sizes(nil, _) ->
     nil;
 reduce_sizes(_, nil) ->
     nil;
-reduce_sizes(#size_info{}=S1, #size_info{}=S2) ->
+reduce_sizes(#size_info{} = S1, #size_info{} = S2) ->
     #size_info{
         active = S1#size_info.active + S2#size_info.active,
         external = S1#size_info.external + S2#size_info.external
@@ -1107,7 +1091,6 @@ reduce_sizes(S1, S2) ->
     US2 = couch_db_updater:upgrade_sizes(S2),
     reduce_sizes(US1, US2).
 
-
 active_size(#st{} = St, #size_info{} = SI) ->
     Trees = [
         St#st.id_tree,
@@ -1116,27 +1099,32 @@ active_size(#st{} = St, #size_info{} = SI) ->
         St#st.purge_tree,
         St#st.purge_seq_tree
     ],
-    lists:foldl(fun(T, Acc) ->
-        case couch_btree:size(T) of
-            _ when Acc == null ->
-                null;
-            nil ->
-                null;
-            Size ->
-                Acc + Size
-        end
-    end, SI#size_info.active, Trees).
-
+    lists:foldl(
+        fun(T, Acc) ->
+            case couch_btree:size(T) of
+                _ when Acc == null ->
+                    null;
+                nil ->
+                    null;
+                Size ->
+                    Acc + Size
+            end
+        end,
+        SI#size_info.active,
+        Trees
+    ).
 
 fold_docs_int(St, Tree, UserFun, UserAcc, Options) ->
-    Fun = case lists:member(include_deleted, Options) of
-        true -> fun include_deleted/4;
-        false -> fun skip_deleted/4
-    end,
-    RedFun = case lists:member(include_reductions, Options) of
-        true -> fun include_reductions/4;
-        false -> fun drop_reductions/4
-    end,
+    Fun =
+        case lists:member(include_deleted, Options) of
+            true -> fun include_deleted/4;
+            false -> fun skip_deleted/4
+        end,
+    RedFun =
+        case lists:member(include_reductions, Options) of
+            true -> fun include_reductions/4;
+            false -> fun drop_reductions/4
+        end,
     InAcc = {RedFun, {UserFun, UserAcc}},
     {ok, Reds, OutAcc} = couch_btree:fold(Tree, Fun, InAcc, Options),
     {_, {_, FinalUserAcc}} = OutAcc,
@@ -1149,12 +1137,10 @@ fold_docs_int(St, Tree, UserFun, UserAcc, Options) ->
             {ok, FinalUserAcc}
     end.
 
-
 include_deleted(Case, Entry, Reds, {UserFun, UserAcc}) ->
     {Go, NewUserAcc} = UserFun(Case, Entry, Reds, UserAcc),
     {Go, {UserFun, NewUserAcc}}.
 
-
 % First element of the reductions is the total
 % number of undeleted documents.
 skip_deleted(traverse, _Entry, {0, _, _} = _Reds, Acc) ->
@@ -1165,27 +1151,23 @@ skip_deleted(Case, Entry, Reds, {UserFun, UserAcc}) ->
     {Go, NewUserAcc} = UserFun(Case, Entry, Reds, UserAcc),
     {Go, {UserFun, NewUserAcc}}.
 
-
 include_reductions(visit, FDI, Reds, {UserFun, UserAcc}) ->
     {Go, NewUserAcc} = UserFun(FDI, Reds, UserAcc),
     {Go, {UserFun, NewUserAcc}};
 include_reductions(_, _, _, Acc) ->
     {ok, Acc}.
 
-
 drop_reductions(visit, FDI, _Reds, {UserFun, UserAcc}) ->
     {Go, NewUserAcc} = UserFun(FDI, UserAcc),
     {Go, {UserFun, NewUserAcc}};
 drop_reductions(_, _, _, Acc) ->
     {ok, Acc}.
 
-
 fold_docs_reduce_to_count(Reds) ->
     RedFun = fun id_tree_reduce/2,
     FinalRed = couch_btree:final_reduce(RedFun, Reds),
     element(1, FinalRed).
 
-
 finish_compaction_int(#st{} = OldSt, #st{} = NewSt1) ->
     #st{
         filepath = FilePath,
@@ -1233,10 +1215,11 @@ finish_compaction_int(#st{} = OldSt, #st{} = NewSt1) ->
     decref(OldSt),
 
     % And return our finished new state
-    {ok, NewSt2#st{
-        filepath = FilePath
-    }, undefined}.
-
+    {ok,
+        NewSt2#st{
+            filepath = FilePath
+        },
+        undefined}.
 
 is_file(Path) ->
     case file:read_file_info(Path, [raw]) of
