@@ -16,10 +16,10 @@
 
 -include_lib("couch/include/couch_db.hrl").
 
-
 -define(INITIAL_WAIT, 60000).
 -define(MONITOR_CHECK, 10000).
--define(SIZE_BLOCK, 16#1000). % 4 KiB
+% 4 KiB
+-define(SIZE_BLOCK, 16#1000).
 -define(IS_OLD_STATE(S), is_pid(S#file.db_monitor)).
 -define(PREFIX_SIZE, 5).
 -define(DEFAULT_READ_COUNT, 1024).
@@ -39,11 +39,11 @@
 % public API
 -export([open/1, open/2, close/1, bytes/1, sync/1, truncate/2, set_db_pid/2]).
 -export([pread_term/2, pread_iolist/2, pread_binary/2]).
--export([append_binary/2, append_binary_md5/2]).
--export([append_raw_chunk/2, assemble_file_chunk/1, assemble_file_chunk/2]).
--export([append_term/2, append_term/3, append_term_md5/2, append_term_md5/3]).
--export([pread_terms/2, pread_binaries/2, pread_iolists/2]).
--export([append_terms/2, append_terms/3, append_binaries/2]).
+-export([append_binary/2]).
+-export([append_raw_chunk/2, assemble_file_chunk/2]).
+-export([append_term/2, append_term/3]).
+-export([pread_terms/2]).
+-export([append_terms/2, append_terms/3]).
 -export([write_header/2, read_header/1]).
 -export([delete/2, delete/3, nuke_dir/2, init_delete_dir/1]).
 -export([last_read/1]).
@@ -66,38 +66,48 @@ open(Filepath) ->
     open(Filepath, []).
 
 open(Filepath, Options) ->
-    case gen_server:start_link(couch_file,
-            {Filepath, Options, self(), Ref = make_ref()}, []) of
-    {ok, Fd} ->
-        {ok, Fd};
-    ignore ->
-        % get the error
-        receive
-        {Ref, Pid, {error, Reason} = Error} ->
-            case process_info(self(), trap_exit) of
-            {trap_exit, true} -> receive {'EXIT', Pid, _} -> ok end;
-            {trap_exit, false} -> ok
-            end,
-            case {lists:member(nologifmissing, Options), Reason} of
-            {true, enoent} -> ok;
-            _ ->
-            couch_log:error("Could not open file ~s: ~s",
-                            [Filepath, file:format_error(Reason)])
-            end,
+    case
+        gen_server:start_link(
+            couch_file,
+            {Filepath, Options, self(), Ref = make_ref()},
+            []
+        )
+    of
+        {ok, Fd} ->
+            {ok, Fd};
+        ignore ->
+            % get the error
+            receive
+                {Ref, Pid, {error, Reason} = Error} ->
+                    case process_info(self(), trap_exit) of
+                        {trap_exit, true} ->
+                            receive
+                                {'EXIT', Pid, _} -> ok
+                            end;
+                        {trap_exit, false} ->
+                            ok
+                    end,
+                    case {lists:member(nologifmissing, Options), Reason} of
+                        {true, enoent} ->
+                            ok;
+                        _ ->
+                            couch_log:error(
+                                "Could not open file ~s: ~s",
+                                [Filepath, file:format_error(Reason)]
+                            )
+                    end,
+                    Error
+            end;
+        Error ->
+            % We can't say much here, because it could be any kind of error.
+            % Just let it bubble and an encapsulating subcomponent can perhaps
+            % be more informative. It will likely appear in the SASL log, anyway.
             Error
-        end;
-    Error ->
-        % We can't say much here, because it could be any kind of error.
-        % Just let it bubble and an encapsulating subcomponent can perhaps
-        % be more informative. It will likely appear in the SASL log, anyway.
-        Error
     end.
 
-
 set_db_pid(Fd, Pid) ->
     gen_server:call(Fd, {set_db_pid, Pid}).
 
-
 %%----------------------------------------------------------------------
 %% Purpose: To append an Erlang term to the end of the file.
 %% Args:    Erlang term to serialize and append to the file.
@@ -114,14 +124,6 @@ append_term(Fd, Term, Options) ->
     Comp = couch_util:get_value(compression, Options, ?DEFAULT_COMPRESSION),
     append_binary(Fd, couch_compress:compress(Term, Comp)).
 
-append_term_md5(Fd, Term) ->
-    append_term_md5(Fd, Term, []).
-
-append_term_md5(Fd, Term, Options) ->
-    Comp = couch_util:get_value(compression, Options, ?DEFAULT_COMPRESSION),
-    append_binary_md5(Fd, couch_compress:compress(Term, Comp)).
-
-
 %%----------------------------------------------------------------------
 %% Purpose: To append an Erlang binary to the end of the file.
 %% Args:    Erlang term to serialize and append to the file.
@@ -133,15 +135,9 @@ append_term_md5(Fd, Term, Options) ->
 append_binary(Fd, Bin) ->
     ioq:call(Fd, {append_bin, assemble_file_chunk(Bin)}, erlang:get(io_priority)).
 
-append_binary_md5(Fd, Bin) ->
-    ioq:call(Fd,
-        {append_bin, assemble_file_chunk(Bin, couch_hash:md5_hash(Bin))},
-        erlang:get(io_priority)).
-
 append_raw_chunk(Fd, Chunk) ->
     ioq:call(Fd, {append_bin, Chunk}, erlang:get(io_priority)).
 
-
 assemble_file_chunk(Bin) ->
     [<<0:1/integer, (iolist_size(Bin)):31/integer>>, Bin].
 
@@ -155,12 +151,10 @@ assemble_file_chunk(Bin, Md5) ->
 %%  or {error, Reason}.
 %%----------------------------------------------------------------------
 
-
 pread_term(Fd, Pos) ->
     {ok, Bin} = pread_binary(Fd, Pos),
     {ok, couch_compress:decompress(Bin)}.
 
-
 %%----------------------------------------------------------------------
 %% Purpose: Reads a binrary from a file that was written with append_binary
 %% Args:    Pos, the offset into the file where the term is serialized.
@@ -172,7 +166,6 @@ pread_binary(Fd, Pos) ->
     {ok, L} = pread_iolist(Fd, Pos),
     {ok, iolist_to_binary(L)}.
 
-
 pread_iolist(Fd, Pos) ->
     case ioq:call(Fd, {pread_iolist, Pos}, erlang:get(io_priority)) of
         {ok, IoList, Md5} ->
@@ -181,49 +174,52 @@ pread_iolist(Fd, Pos) ->
             Error
     end.
 
-
 pread_terms(Fd, PosList) ->
     {ok, Bins} = pread_binaries(Fd, PosList),
-    Terms = lists:map(fun(Bin) ->
-        couch_compress:decompress(Bin)
-    end, Bins),
+    Terms = lists:map(
+        fun(Bin) ->
+            couch_compress:decompress(Bin)
+        end,
+        Bins
+    ),
     {ok, Terms}.
 
-
 pread_binaries(Fd, PosList) ->
     {ok, Data} = pread_iolists(Fd, PosList),
     {ok, lists:map(fun erlang:iolist_to_binary/1, Data)}.
 
-
 pread_iolists(Fd, PosList) ->
     case ioq:call(Fd, {pread_iolists, PosList}, erlang:get(io_priority)) of
         {ok, DataMd5s} ->
-            Data = lists:zipwith(fun(Pos, {IoList, Md5}) ->
-                verify_md5(Fd, Pos, IoList, Md5)
-            end, PosList, DataMd5s),
+            Data = lists:zipwith(
+                fun(Pos, {IoList, Md5}) ->
+                    verify_md5(Fd, Pos, IoList, Md5)
+                end,
+                PosList,
+                DataMd5s
+            ),
             {ok, Data};
         Error ->
             Error
     end.
 
-
 append_terms(Fd, Terms) ->
     append_terms(Fd, Terms, []).
 
-
 append_terms(Fd, Terms, Options) ->
     Comp = couch_util:get_value(compression, Options, ?DEFAULT_COMPRESSION),
-    Bins = lists:map(fun(Term) ->
-        couch_compress:compress(Term, Comp)
-    end, Terms),
+    Bins = lists:map(
+        fun(Term) ->
+            couch_compress:compress(Term, Comp)
+        end,
+        Terms
+    ),
     append_binaries(Fd, Bins).
 
-
 append_binaries(Fd, Bins) ->
     WriteBins = lists:map(fun assemble_file_chunk/1, Bins),
     ioq:call(Fd, {append_bins, WriteBins}, erlang:get(io_priority)).
 
-
 %%----------------------------------------------------------------------
 %% Purpose: The length of a file, in bytes.
 %% Returns: {ok, Bytes}
@@ -280,36 +276,42 @@ sync(Fd) ->
 close(Fd) ->
     gen_server:call(Fd, close, infinity).
 
-
 delete(RootDir, Filepath) ->
     delete(RootDir, Filepath, []).
 
 delete(RootDir, FullFilePath, Options) ->
-    EnableRecovery = config:get_boolean("couchdb",
-        "enable_database_recovery", false),
+    EnableRecovery = config:get_boolean(
+        "couchdb",
+        "enable_database_recovery",
+        false
+    ),
     Async = not lists:member(sync, Options),
     Context = couch_util:get_value(context, Options, compaction),
     case Context =:= delete andalso EnableRecovery of
         true ->
             rename_file(FullFilePath);
         false ->
-            DeleteAfterRename = config:get_boolean("couchdb",
-                "delete_after_rename", true),
+            DeleteAfterRename = config:get_boolean(
+                "couchdb",
+                "delete_after_rename",
+                true
+            ),
             delete_file(RootDir, FullFilePath, Async, DeleteAfterRename)
     end.
 
 delete_file(RootDir, Filepath, Async, DeleteAfterRename) ->
-    DelFile = filename:join([RootDir,".delete", ?b2l(couch_uuids:random())]),
+    DelFile = filename:join([RootDir, ".delete", ?b2l(couch_uuids:random())]),
     case file:rename(Filepath, DelFile) of
-    ok when DeleteAfterRename ->
-        if (Async) ->
-            spawn(file, delete, [DelFile]),
-            ok;
-        true ->
-            file:delete(DelFile)
-        end;
-    Else ->
-        Else
+        ok when DeleteAfterRename ->
+            if
+                (Async) ->
+                    spawn(file, delete, [DelFile]),
+                    ok;
+                true ->
+                    file:delete(DelFile)
+            end;
+        Else ->
+            Else
     end.
 
 rename_file(Original) ->
@@ -323,14 +325,21 @@ rename_file(Original) ->
 deleted_filename(Original) ->
     {{Y, Mon, D}, {H, Min, S}} = calendar:universal_time(),
     Suffix = lists:flatten(
-        io_lib:format(".~w~2.10.0B~2.10.0B."
-            ++ "~2.10.0B~2.10.0B~2.10.0B.deleted"
-            ++ filename:extension(Original), [Y, Mon, D, H, Min, S])),
+        io_lib:format(
+            ".~w~2.10.0B~2.10.0B." ++
+                "~2.10.0B~2.10.0B~2.10.0B.deleted" ++
+                filename:extension(Original),
+            [Y, Mon, D, H, Min, S]
+        )
+    ),
     filename:rootname(Original) ++ Suffix.
 
 nuke_dir(RootDelDir, Dir) ->
-    EnableRecovery = config:get_boolean("couchdb",
-        "enable_database_recovery", false),
+    EnableRecovery = config:get_boolean(
+        "couchdb",
+        "enable_database_recovery",
+        false
+    ),
     case EnableRecovery of
         true ->
             rename_file(Dir);
@@ -339,8 +348,11 @@ nuke_dir(RootDelDir, Dir) ->
     end.
 
 delete_dir(RootDelDir, Dir) ->
-    DeleteAfterRename = config:get_boolean("couchdb",
-        "delete_after_rename", true),
+    DeleteAfterRename = config:get_boolean(
+        "couchdb",
+        "delete_after_rename",
+        true
+    ),
     FoldFun = fun(File) ->
         Path = Dir ++ "/" ++ File,
         case filelib:is_dir(Path) of
@@ -359,27 +371,30 @@ delete_dir(RootDelDir, Dir) ->
             ok
     end.
 
-
 init_delete_dir(RootDir) ->
-    Dir = filename:join(RootDir,".delete"),
+    Dir = filename:join(RootDir, ".delete"),
     % note: ensure_dir requires an actual filename companent, which is the
     % reason for "foo".
-    filelib:ensure_dir(filename:join(Dir,"foo")),
+    filelib:ensure_dir(filename:join(Dir, "foo")),
     spawn(fun() ->
-        filelib:fold_files(Dir, ".*", true,
+        filelib:fold_files(
+            Dir,
+            ".*",
+            true,
             fun(Filename, _) ->
                 ok = file:delete(Filename)
-            end, ok)
+            end,
+            ok
+        )
     end),
     ok.
 
-
 read_header(Fd) ->
     case ioq:call(Fd, find_header, erlang:get(io_priority)) of
-    {ok, Bin} ->
-        {ok, binary_to_term(Bin)};
-    Else ->
-        Else
+        {ok, Bin} ->
+            {ok, binary_to_term(Bin)};
+        Else ->
+            Else
     end.
 
 write_header(Fd, Data) ->
@@ -389,17 +404,14 @@ write_header(Fd, Data) ->
     FinalBin = <<Md5/binary, Bin/binary>>,
     ioq:call(Fd, {write_header, FinalBin}, erlang:get(io_priority)).
 
-
 init_status_error(ReturnPid, Ref, Error) ->
     ReturnPid ! {Ref, self(), Error},
     ignore.
 
-
 last_read(Fd) when is_pid(Fd) ->
     Now = os:timestamp(),
     couch_util:process_dict_get(Fd, read_timestamp, Now).
 
-
 % server functions
 
 init({Filepath, Options, ReturnPid, Ref}) ->
@@ -408,66 +420,67 @@ init({Filepath, Options, ReturnPid, Ref}) ->
     IsSys = lists:member(sys_db, Options),
     update_read_timestamp(),
     case lists:member(create, Options) of
-    true ->
-        filelib:ensure_dir(Filepath),
-        case file:open(Filepath, OpenOptions) of
-        {ok, Fd} ->
-            %% Save Fd in process dictionary for debugging purposes
-            put(couch_file_fd, {Fd, Filepath}),
-            {ok, Length} = file:position(Fd, eof),
-            case Length > 0 of
-            true ->
-                % this means the file already exists and has data.
-                % FYI: We don't differentiate between empty files and non-existant
-                % files here.
-                case lists:member(overwrite, Options) of
-                true ->
-                    {ok, 0} = file:position(Fd, 0),
-                    ok = file:truncate(Fd),
-                    ok = file:sync(Fd),
-                    maybe_track_open_os_files(Options),
-                    erlang:send_after(?INITIAL_WAIT, self(), maybe_close),
-                    {ok, #file{fd=Fd, is_sys=IsSys, pread_limit=Limit}};
-                false ->
-                    ok = file:close(Fd),
-                    init_status_error(ReturnPid, Ref, {error, eexist})
-                end;
-            false ->
-                maybe_track_open_os_files(Options),
-                erlang:send_after(?INITIAL_WAIT, self(), maybe_close),
-                {ok, #file{fd=Fd, is_sys=IsSys, pread_limit=Limit}}
-            end;
-        Error ->
-            init_status_error(ReturnPid, Ref, Error)
-        end;
-    false ->
-        % open in read mode first, so we don't create the file if it doesn't exist.
-        case file:open(Filepath, [read, raw]) of
-        {ok, Fd_Read} ->
+        true ->
+            filelib:ensure_dir(Filepath),
             case file:open(Filepath, OpenOptions) of
                 {ok, Fd} ->
-                     %% Save Fd in process dictionary for debugging purposes
-                     put(couch_file_fd, {Fd, Filepath}),
-                     ok = file:close(Fd_Read),
-                     maybe_track_open_os_files(Options),
-                     {ok, Eof} = file:position(Fd, eof),
-                     erlang:send_after(?INITIAL_WAIT, self(), maybe_close),
-                     {ok, #file{fd=Fd, eof=Eof, is_sys=IsSys, pread_limit=Limit}};
-                 Error ->
-                     init_status_error(ReturnPid, Ref, Error)
+                    %% Save Fd in process dictionary for debugging purposes
+                    put(couch_file_fd, {Fd, Filepath}),
+                    {ok, Length} = file:position(Fd, eof),
+                    case Length > 0 of
+                        true ->
+                            % this means the file already exists and has data.
+                            % FYI: We don't differentiate between empty files and non-existant
+                            % files here.
+                            case lists:member(overwrite, Options) of
+                                true ->
+                                    {ok, 0} = file:position(Fd, 0),
+                                    ok = file:truncate(Fd),
+                                    ok = file:sync(Fd),
+                                    maybe_track_open_os_files(Options),
+                                    erlang:send_after(?INITIAL_WAIT, self(), maybe_close),
+                                    {ok, #file{fd = Fd, is_sys = IsSys, pread_limit = Limit}};
+                                false ->
+                                    ok = file:close(Fd),
+                                    init_status_error(ReturnPid, Ref, {error, eexist})
+                            end;
+                        false ->
+                            maybe_track_open_os_files(Options),
+                            erlang:send_after(?INITIAL_WAIT, self(), maybe_close),
+                            {ok, #file{fd = Fd, is_sys = IsSys, pread_limit = Limit}}
+                    end;
+                Error ->
+                    init_status_error(ReturnPid, Ref, Error)
             end;
-        Error ->
-            init_status_error(ReturnPid, Ref, Error)
-        end
+        false ->
+            % open in read mode first, so we don't create the file if it doesn't exist.
+            case file:open(Filepath, [read, raw]) of
+                {ok, Fd_Read} ->
+                    case file:open(Filepath, OpenOptions) of
+                        {ok, Fd} ->
+                            %% Save Fd in process dictionary for debugging purposes
+                            put(couch_file_fd, {Fd, Filepath}),
+                            ok = file:close(Fd_Read),
+                            maybe_track_open_os_files(Options),
+                            {ok, Eof} = file:position(Fd, eof),
+                            erlang:send_after(?INITIAL_WAIT, self(), maybe_close),
+                            {ok, #file{fd = Fd, eof = Eof, is_sys = IsSys, pread_limit = Limit}};
+                        Error ->
+                            init_status_error(ReturnPid, Ref, Error)
+                    end;
+                Error ->
+                    init_status_error(ReturnPid, Ref, Error)
+            end
     end.
 
 file_open_options(Options) ->
-    [read, raw, binary] ++ case lists:member(read_only, Options) of
-    true ->
-        [];
-    false ->
-        [append]
-    end.
+    [read, raw, binary] ++
+        case lists:member(read_only, Options) of
+            true ->
+                [];
+            false ->
+                [append]
+        end.
 
 maybe_track_open_os_files(Options) ->
     case not lists:member(sys_db, Options) of
@@ -484,59 +497,62 @@ terminate(_Reason, #file{fd = Fd}) ->
 
 handle_call(Msg, From, File) when ?IS_OLD_STATE(File) ->
     handle_call(Msg, From, upgrade_state(File));
-
-handle_call(close, _From, #file{fd=Fd}=File) ->
+handle_call(close, _From, #file{fd = Fd} = File) ->
     {stop, normal, file:close(Fd), File#file{fd = nil}};
-
 handle_call({pread_iolist, Pos}, _From, File) ->
     update_read_timestamp(),
     {LenIolist, NextPos} = read_raw_iolist_int(File, Pos, 4),
     case iolist_to_binary(LenIolist) of
-    <<1:1/integer,Len:31/integer>> -> % an MD5-prefixed term
-        {Md5AndIoList, _} = read_raw_iolist_int(File, NextPos, Len+16),
-        {Md5, IoList} = extract_md5(Md5AndIoList),
-        {reply, {ok, IoList, Md5}, File};
-    <<0:1/integer,Len:31/integer>> ->
-        {Iolist, _} = read_raw_iolist_int(File, NextPos, Len),
-        {reply, {ok, Iolist, <<>>}, File}
+        % an MD5-prefixed term
+        <<1:1/integer, Len:31/integer>> ->
+            {Md5AndIoList, _} = read_raw_iolist_int(File, NextPos, Len + 16),
+            {Md5, IoList} = extract_md5(Md5AndIoList),
+            {reply, {ok, IoList, Md5}, File};
+        <<0:1/integer, Len:31/integer>> ->
+            {Iolist, _} = read_raw_iolist_int(File, NextPos, Len),
+            {reply, {ok, Iolist, <<>>}, File}
     end;
-
 handle_call({pread_iolists, PosL}, _From, File) ->
     update_read_timestamp(),
     LocNums1 = [{Pos, 4} || Pos <- PosL],
     DataSizes = read_multi_raw_iolists_int(File, LocNums1),
-    LocNums2 = lists:map(fun({LenIoList, NextPos}) ->
-        case iolist_to_binary(LenIoList) of
-            <<1:1/integer, Len:31/integer>> -> % an MD5-prefixed term
-                {NextPos, Len + 16};
-            <<0:1/integer, Len:31/integer>> ->
-                {NextPos, Len}
-        end
-    end, DataSizes),
+    LocNums2 = lists:map(
+        fun({LenIoList, NextPos}) ->
+            case iolist_to_binary(LenIoList) of
+                % an MD5-prefixed term
+                <<1:1/integer, Len:31/integer>> ->
+                    {NextPos, Len + 16};
+                <<0:1/integer, Len:31/integer>> ->
+                    {NextPos, Len}
+            end
+        end,
+        DataSizes
+    ),
     Resps = read_multi_raw_iolists_int(File, LocNums2),
-    Extracted = lists:zipwith(fun({LenIoList, _}, {IoList, _}) ->
-        case iolist_to_binary(LenIoList) of
-            <<1:1/integer, _:31/integer>> ->
-                {Md5, IoList} = extract_md5(IoList),
-                {IoList, Md5};
-            <<0:1/integer, _:31/integer>> ->
-                {IoList, <<>>}
-        end
-    end, DataSizes, Resps),
+    Extracted = lists:zipwith(
+        fun({LenIoList, _}, {IoList, _}) ->
+            case iolist_to_binary(LenIoList) of
+                <<1:1/integer, _:31/integer>> ->
+                    {Md5, IoList} = extract_md5(IoList),
+                    {IoList, Md5};
+                <<0:1/integer, _:31/integer>> ->
+                    {IoList, <<>>}
+            end
+        end,
+        DataSizes,
+        Resps
+    ),
     {reply, {ok, Extracted}, File};
-
 handle_call(bytes, _From, #file{fd = Fd} = File) ->
     {reply, file:position(Fd, eof), File};
-
-handle_call({set_db_pid, Pid}, _From, #file{db_monitor=OldRef}=File) ->
+handle_call({set_db_pid, Pid}, _From, #file{db_monitor = OldRef} = File) ->
     case is_reference(OldRef) of
         true -> demonitor(OldRef, [flush]);
         false -> ok
     end,
     Ref = monitor(process, Pid),
-    {reply, ok, File#file{db_monitor=Ref}};
-
-handle_call(sync, _From, #file{fd=Fd}=File) ->
+    {reply, ok, File#file{db_monitor = Ref}};
+handle_call(sync, _From, #file{fd = Fd} = File) ->
     case file:sync(Fd) of
         ok ->
             {reply, ok, File};
@@ -547,68 +563,66 @@ handle_call(sync, _From, #file{fd=Fd}=File) ->
             % can't fathom.
             {stop, Error, Error, #file{fd = nil}}
     end;
-
-handle_call({truncate, Pos}, _From, #file{fd=Fd}=File) ->
+handle_call({truncate, Pos}, _From, #file{fd = Fd} = File) ->
     {ok, Pos} = file:position(Fd, Pos),
     case file:truncate(Fd) of
-    ok ->
-        {reply, ok, File#file{eof = Pos}};
-    Error ->
-        {reply, Error, File}
+        ok ->
+            {reply, ok, File#file{eof = Pos}};
+        Error ->
+            {reply, Error, File}
     end;
-
 handle_call({append_bin, Bin}, _From, #file{fd = Fd, eof = Pos} = File) ->
     Blocks = make_blocks(Pos rem ?SIZE_BLOCK, Bin),
     Size = iolist_size(Blocks),
     case file:write(Fd, Blocks) of
-    ok ->
-        {reply, {ok, Pos, Size}, File#file{eof = Pos + Size}};
-    Error ->
-        {reply, Error, reset_eof(File)}
+        ok ->
+            {reply, {ok, Pos, Size}, File#file{eof = Pos + Size}};
+        Error ->
+            {reply, Error, reset_eof(File)}
     end;
-
 handle_call({append_bins, Bins}, _From, #file{fd = Fd, eof = Pos} = File) ->
-    {BlockResps, FinalPos} = lists:mapfoldl(fun(Bin, PosAcc) ->
-        Blocks = make_blocks(PosAcc rem ?SIZE_BLOCK, Bin),
-        Size = iolist_size(Blocks),
-        {{Blocks, {PosAcc, Size}}, PosAcc + Size}
-    end, Pos, Bins),
+    {BlockResps, FinalPos} = lists:mapfoldl(
+        fun(Bin, PosAcc) ->
+            Blocks = make_blocks(PosAcc rem ?SIZE_BLOCK, Bin),
+            Size = iolist_size(Blocks),
+            {{Blocks, {PosAcc, Size}}, PosAcc + Size}
+        end,
+        Pos,
+        Bins
+    ),
     {AllBlocks, Resps} = lists:unzip(BlockResps),
     case file:write(Fd, AllBlocks) of
-    ok ->
-        {reply, {ok, Resps}, File#file{eof = FinalPos}};
-    Error ->
-        {reply, Error, reset_eof(File)}
+        ok ->
+            {reply, {ok, Resps}, File#file{eof = FinalPos}};
+        Error ->
+            {reply, Error, reset_eof(File)}
     end;
-
 handle_call({write_header, Bin}, _From, #file{fd = Fd, eof = Pos} = File) ->
     BinSize = byte_size(Bin),
     case Pos rem ?SIZE_BLOCK of
-    0 ->
-        Padding = <<>>;
-    BlockOffset ->
-        Padding = <<0:(8*(?SIZE_BLOCK-BlockOffset))>>
+        0 ->
+            Padding = <<>>;
+        BlockOffset ->
+            Padding = <<0:(8 * (?SIZE_BLOCK - BlockOffset))>>
     end,
     FinalBin = [Padding, <<1, BinSize:32/integer>> | make_blocks(5, [Bin])],
     case file:write(Fd, FinalBin) of
-    ok ->
-        {reply, ok, File#file{eof = Pos + iolist_size(FinalBin)}};
-    Error ->
-        {reply, Error, reset_eof(File)}
+        ok ->
+            {reply, ok, File#file{eof = Pos + iolist_size(FinalBin)}};
+        Error ->
+            {reply, Error, reset_eof(File)}
     end;
-
 handle_call(find_header, _From, #file{fd = Fd, eof = Pos} = File) ->
     {reply, find_header(Fd, Pos div ?SIZE_BLOCK), File}.
 
 handle_cast(close, Fd) ->
-    {stop,normal,Fd}.
+    {stop, normal, Fd}.
 
 code_change(_OldVsn, State, _Extra) ->
     {ok, State}.
 
 handle_info(Msg, File) when ?IS_OLD_STATE(File) ->
     handle_info(Msg, upgrade_state(File));
-
 handle_info(maybe_close, File) ->
     case is_idle(File) of
         true ->
@@ -617,8 +631,7 @@ handle_info(maybe_close, File) ->
             erlang:send_after(?MONITOR_CHECK, self(), maybe_close),
             {noreply, File}
     end;
-
-handle_info({'DOWN', Ref, process, _Pid, _Info}, #file{db_monitor=Ref}=File) ->
+handle_info({'DOWN', Ref, process, _Pid, _Info}, #file{db_monitor = Ref} = File) ->
     case is_idle(File) of
         true -> {stop, normal, File};
         false -> {noreply, File}
@@ -630,12 +643,13 @@ format_status(_Opt, [PDict, #file{} = File]) ->
 
 find_header(Fd, Block) ->
     case (catch load_header(Fd, Block)) of
-    {ok, Bin} ->
-        {ok, Bin};
-    _Error ->
-        ReadCount = config:get_integer(
-            "couchdb", "find_header_read_count", ?DEFAULT_READ_COUNT),
-        find_header(Fd, Block -1, ReadCount)
+        {ok, Bin} ->
+            {ok, Bin};
+        _Error ->
+            ReadCount = config:get_integer(
+                "couchdb", "find_header_read_count", ?DEFAULT_READ_COUNT
+            ),
+            find_header(Fd, Block - 1, ReadCount)
     end.
 
 load_header(Fd, Block) ->
@@ -648,22 +662,22 @@ load_header(Fd, Pos, HeaderLen) ->
 
 load_header(Fd, Pos, HeaderLen, RestBlock) ->
     TotalBytes = calculate_total_read_len(?PREFIX_SIZE, HeaderLen),
-    RawBin = case TotalBytes =< byte_size(RestBlock) of
-        true ->
-            <<RawBin0:TotalBytes/binary, _/binary>> = RestBlock,
-            RawBin0;
-        false ->
-            ReadStart = Pos + ?PREFIX_SIZE + byte_size(RestBlock),
-            ReadLen = TotalBytes - byte_size(RestBlock),
-            {ok, Missing} = file:pread(Fd, ReadStart, ReadLen),
-            <<RestBlock/binary, Missing/binary>>
-    end,
+    RawBin =
+        case TotalBytes =< byte_size(RestBlock) of
+            true ->
+                <<RawBin0:TotalBytes/binary, _/binary>> = RestBlock,
+                RawBin0;
+            false ->
+                ReadStart = Pos + ?PREFIX_SIZE + byte_size(RestBlock),
+                ReadLen = TotalBytes - byte_size(RestBlock),
+                {ok, Missing} = file:pread(Fd, ReadStart, ReadLen),
+                <<RestBlock/binary, Missing/binary>>
+        end,
     <<Md5Sig:16/binary, HeaderBin/binary>> =
         iolist_to_binary(remove_block_prefixes(?PREFIX_SIZE, RawBin)),
     Md5Sig = couch_hash:md5_hash(HeaderBin),
     {ok, HeaderBin}.
 
-
 %% Read multiple block locations using a single file:pread/2.
 -spec find_header(file:fd(), block_id(), non_neg_integer()) ->
     {ok, binary()} | no_valid_header.
@@ -671,23 +685,28 @@ find_header(_Fd, Block, _ReadCount) when Block < 0 ->
     no_valid_header;
 find_header(Fd, Block, ReadCount) ->
     FirstBlock = max(0, Block - ReadCount + 1),
-    BlockLocations = [?SIZE_BLOCK*B || B <- lists:seq(FirstBlock, Block)],
+    BlockLocations = [?SIZE_BLOCK * B || B <- lists:seq(FirstBlock, Block)],
     {ok, DataL} = file:pread(Fd, [{L, ?PREFIX_SIZE} || L <- BlockLocations]),
     %% Since BlockLocations are ordered from oldest to newest, we rely
     %% on lists:foldl/3 to reverse the order, making HeaderLocations
     %% correctly ordered from newest to oldest.
-    HeaderLocations = lists:foldl(fun
-        ({Loc, <<1, HeaderSize:32/integer>>}, Acc) ->
-            [{Loc, HeaderSize} | Acc];
-        (_, Acc) ->
-            Acc
-    end, [], lists:zip(BlockLocations, DataL)),
+    HeaderLocations = lists:foldl(
+        fun
+            ({Loc, <<1, HeaderSize:32/integer>>}, Acc) ->
+                [{Loc, HeaderSize} | Acc];
+            (_, Acc) ->
+                Acc
+        end,
+        [],
+        lists:zip(BlockLocations, DataL)
+    ),
     case find_newest_header(Fd, HeaderLocations) of
         {ok, _Location, HeaderBin} ->
             {ok, HeaderBin};
         _ ->
             ok = file:advise(
-                Fd, hd(BlockLocations), ReadCount * ?SIZE_BLOCK, dont_need),
+                Fd, hd(BlockLocations), ReadCount * ?SIZE_BLOCK, dont_need
+            ),
             NextBlock = hd(BlockLocations) div ?SIZE_BLOCK - 1,
             find_header(Fd, NextBlock, ReadCount)
     end.
@@ -704,10 +723,10 @@ find_newest_header(Fd, [{Location, Size} | LocationSizes]) ->
             find_newest_header(Fd, LocationSizes)
     end.
 
-
--spec read_raw_iolist_int(#file{}, Pos::non_neg_integer(), Len::non_neg_integer()) ->
-    {Data::iolist(), CurPos::non_neg_integer()}.
-read_raw_iolist_int(Fd, {Pos, _Size}, Len) -> % 0110 UPGRADE CODE
+-spec read_raw_iolist_int(#file{}, Pos :: non_neg_integer(), Len :: non_neg_integer()) ->
+    {Data :: iolist(), CurPos :: non_neg_integer()}.
+% 0110 UPGRADE CODE
+read_raw_iolist_int(Fd, {Pos, _Size}, Len) ->
     read_raw_iolist_int(Fd, Pos, Len);
 read_raw_iolist_int(#file{fd = Fd} = File, Pos, Len) ->
     {Pos, TotalBytes} = get_pread_locnum(File, Pos, Len),
@@ -727,33 +746,38 @@ read_raw_iolist_int(#file{fd = Fd} = File, Pos, Len) ->
 
 % TODO: check if this is really unused
 read_multi_raw_iolists_int(#file{fd = Fd} = File, PosLens) ->
-    LocNums = lists:map(fun({Pos, Len}) ->
-        get_pread_locnum(File, Pos, Len)
-    end, PosLens),
+    LocNums = lists:map(
+        fun({Pos, Len}) ->
+            get_pread_locnum(File, Pos, Len)
+        end,
+        PosLens
+    ),
     {ok, Bins} = file:pread(Fd, LocNums),
-    lists:zipwith(fun({Pos, TotalBytes}, Bin) ->
-        <<RawBin:TotalBytes/binary>> = Bin,
-        {remove_block_prefixes(Pos rem ?SIZE_BLOCK, RawBin), Pos + TotalBytes}
-    end, LocNums, Bins).
-
+    lists:zipwith(
+        fun({Pos, TotalBytes}, Bin) ->
+            <<RawBin:TotalBytes/binary>> = Bin,
+            {remove_block_prefixes(Pos rem ?SIZE_BLOCK, RawBin), Pos + TotalBytes}
+        end,
+        LocNums,
+        Bins
+    ).
 
 get_pread_locnum(File, Pos, Len) ->
     BlockOffset = Pos rem ?SIZE_BLOCK,
     TotalBytes = calculate_total_read_len(BlockOffset, Len),
     case Pos + TotalBytes of
-    Size when Size > File#file.eof ->
-        couch_stats:increment_counter([pread, exceed_eof]),
-        {_Fd, Filepath} = get(couch_file_fd),
-        throw({read_beyond_eof, Filepath});
-    Size when Size > File#file.pread_limit ->
-        couch_stats:increment_counter([pread, exceed_limit]),
-        {_Fd, Filepath} = get(couch_file_fd),
-        throw({exceed_pread_limit, Filepath, File#file.pread_limit});
-    _ ->
-        {Pos, TotalBytes}
+        Size when Size > File#file.eof ->
+            couch_stats:increment_counter([pread, exceed_eof]),
+            {_Fd, Filepath} = get(couch_file_fd),
+            throw({read_beyond_eof, Filepath});
+        Size when Size > File#file.pread_limit ->
+            couch_stats:increment_counter([pread, exceed_limit]),
+            {_Fd, Filepath} = get(couch_file_fd),
+            throw({exceed_pread_limit, Filepath, File#file.pread_limit});
+        _ ->
+            {Pos, TotalBytes}
     end.
 
-
 -spec extract_md5(iolist()) -> {binary(), iolist()}.
 extract_md5(FullIoList) ->
     {Md5List, IoList} = split_iolist(FullIoList, 16, []),
@@ -763,26 +787,28 @@ calculate_total_read_len(0, FinalLen) ->
     calculate_total_read_len(1, FinalLen) + 1;
 calculate_total_read_len(BlockOffset, FinalLen) ->
     case ?SIZE_BLOCK - BlockOffset of
-    BlockLeft when BlockLeft >= FinalLen ->
-        FinalLen;
-    BlockLeft ->
-        FinalLen + ((FinalLen - BlockLeft) div (?SIZE_BLOCK -1)) +
-            if ((FinalLen - BlockLeft) rem (?SIZE_BLOCK -1)) =:= 0 -> 0;
-                true -> 1 end
+        BlockLeft when BlockLeft >= FinalLen ->
+            FinalLen;
+        BlockLeft ->
+            FinalLen + ((FinalLen - BlockLeft) div (?SIZE_BLOCK - 1)) +
+                if
+                    ((FinalLen - BlockLeft) rem (?SIZE_BLOCK - 1)) =:= 0 -> 0;
+                    true -> 1
+                end
     end.
 
 remove_block_prefixes(_BlockOffset, <<>>) ->
     [];
-remove_block_prefixes(0, <<_BlockPrefix,Rest/binary>>) ->
+remove_block_prefixes(0, <<_BlockPrefix, Rest/binary>>) ->
     remove_block_prefixes(1, Rest);
 remove_block_prefixes(BlockOffset, Bin) ->
     BlockBytesAvailable = ?SIZE_BLOCK - BlockOffset,
     case size(Bin) of
-    Size when Size > BlockBytesAvailable ->
-        <<DataBlock:BlockBytesAvailable/binary,Rest/binary>> = Bin,
-        [DataBlock | remove_block_prefixes(0, Rest)];
-    _Size ->
-        [Bin]
+        Size when Size > BlockBytesAvailable ->
+            <<DataBlock:BlockBytesAvailable/binary, Rest/binary>> = Bin,
+            [DataBlock | remove_block_prefixes(0, Rest)];
+        _Size ->
+            [Bin]
     end.
 
 make_blocks(_BlockOffset, []) ->
@@ -791,16 +817,16 @@ make_blocks(0, IoList) ->
     [<<0>> | make_blocks(1, IoList)];
 make_blocks(BlockOffset, IoList) ->
     case split_iolist(IoList, (?SIZE_BLOCK - BlockOffset), []) of
-    {Begin, End} ->
-        [Begin | make_blocks(0, End)];
-    _SplitRemaining ->
-        IoList
+        {Begin, End} ->
+            [Begin | make_blocks(0, End)];
+        _SplitRemaining ->
+            IoList
     end.
 
 %% @doc Returns a tuple where the first element contains the leading SplitAt
 %% bytes of the original iolist, and the 2nd element is the tail. If SplitAt
 %% is larger than byte_size(IoList), return the difference.
--spec split_iolist(IoList::iolist(), SplitAt::non_neg_integer(), Acc::list()) ->
+-spec split_iolist(IoList :: iolist(), SplitAt :: non_neg_integer(), Acc :: list()) ->
     {iolist(), iolist()} | non_neg_integer().
 split_iolist(List, 0, BeginAcc) ->
     {lists:reverse(BeginAcc), List};
@@ -809,14 +835,14 @@ split_iolist([], SplitAt, _BeginAcc) ->
 split_iolist([<<Bin/binary>> | Rest], SplitAt, BeginAcc) when SplitAt > byte_size(Bin) ->
     split_iolist(Rest, SplitAt - byte_size(Bin), [Bin | BeginAcc]);
 split_iolist([<<Bin/binary>> | Rest], SplitAt, BeginAcc) ->
-    <<Begin:SplitAt/binary,End/binary>> = Bin,
+    <<Begin:SplitAt/binary, End/binary>> = Bin,
     split_iolist([End | Rest], 0, [Begin | BeginAcc]);
-split_iolist([Sublist| Rest], SplitAt, BeginAcc) when is_list(Sublist) ->
+split_iolist([Sublist | Rest], SplitAt, BeginAcc) when is_list(Sublist) ->
     case split_iolist(Sublist, SplitAt, BeginAcc) of
-    {Begin, End} ->
-        {Begin, [End | Rest]};
-    SplitRemaining ->
-        split_iolist(Rest, SplitAt - (SplitAt - SplitRemaining), [Sublist | BeginAcc])
+        {Begin, End} ->
+            {Begin, [End | Rest]};
+        SplitRemaining ->
+            split_iolist(Rest, SplitAt - (SplitAt - SplitRemaining), [Sublist | BeginAcc])
     end;
 split_iolist([Byte | Rest], SplitAt, BeginAcc) when is_integer(Byte) ->
     split_iolist(Rest, SplitAt - 1, [Byte | BeginAcc]).
@@ -825,29 +851,25 @@ monitored_by_pids() ->
     {monitored_by, PidsAndRefs} = process_info(self(), monitored_by),
     lists:filter(fun is_pid/1, PidsAndRefs).
 
-
 verify_md5(_Fd, _Pos, IoList, <<>>) ->
     IoList;
-
 verify_md5(Fd, Pos, IoList, Md5) ->
     case couch_hash:md5_hash(IoList) of
         Md5 -> IoList;
         _ -> report_md5_error(Fd, Pos)
     end.
 
-
 report_md5_error(Fd, Pos) ->
     couch_log:emergency("File corruption in ~p at position ~B", [Fd, Pos]),
     exit({file_corruption, <<"file corruption">>}).
 
-
 % System dbs aren't monitored by couch_stats_process_tracker
-is_idle(#file{is_sys=true}) ->
+is_idle(#file{is_sys = true}) ->
     case monitored_by_pids() of
         [] -> true;
         _ -> false
     end;
-is_idle(#file{is_sys=false}) ->
+is_idle(#file{is_sys = false}) ->
     Tracker = whereis(couch_stats_process_tracker),
     case monitored_by_pids() of
         [] -> true;
@@ -865,10 +887,10 @@ process_info(Pid) ->
 update_read_timestamp() ->
     put(read_timestamp, os:timestamp()).
 
-upgrade_state(#file{db_monitor=DbPid}=File) when is_pid(DbPid) ->
+upgrade_state(#file{db_monitor = DbPid} = File) when is_pid(DbPid) ->
     unlink(DbPid),
     Ref = monitor(process, DbPid),
-    File#file{db_monitor=Ref};
+    File#file{db_monitor = Ref};
 upgrade_state(State) ->
     State.
 
@@ -889,21 +911,26 @@ reset_eof(#file{} = File) ->
 deleted_filename_test_() ->
     DbNames = ["dbname", "db.name", "user/dbname"],
     Fixtures = make_filename_fixtures(DbNames),
-    lists:map(fun(Fixture) ->
-        should_create_proper_deleted_filename(Fixture)
-    end, Fixtures).
+    lists:map(
+        fun(Fixture) ->
+            should_create_proper_deleted_filename(Fixture)
+        end,
+        Fixtures
+    ).
 
 should_create_proper_deleted_filename(Before) ->
     {Before,
-    ?_test(begin
-        BeforeExtension = filename:extension(Before),
-        BeforeBasename = filename:basename(Before, BeforeExtension),
-        Re = "^" ++ BeforeBasename ++ "\.[0-9]{8}\.[0-9]{6}\.deleted\..*$",
-        After = deleted_filename(Before),
-        ?assertEqual(match,
-            re:run(filename:basename(After), Re, [{capture, none}])),
-        ?assertEqual(BeforeExtension, filename:extension(After))
-    end)}.
+        ?_test(begin
+            BeforeExtension = filename:extension(Before),
+            BeforeBasename = filename:basename(Before, BeforeExtension),
+            Re = "^" ++ BeforeBasename ++ "\.[0-9]{8}\.[0-9]{6}\.deleted\..*$",
+            After = deleted_filename(Before),
+            ?assertEqual(
+                match,
+                re:run(filename:basename(After), Re, [{capture, none}])
+            ),
+            ?assertEqual(BeforeExtension, filename:extension(After))
+        end)}.
 
 make_filename_fixtures(DbNames) ->
     Formats = [
@@ -912,12 +939,18 @@ make_filename_fixtures(DbNames) ->
         "shards/00000000-1fffffff/~s.1458336317.couch",
         ".shards/00000000-1fffffff/~s.1458336317_design",
         ".shards/00000000-1fffffff/~s.1458336317_design"
-            "/mrview/3133e28517e89a3e11435dd5ac4ad85a.view"
+        "/mrview/3133e28517e89a3e11435dd5ac4ad85a.view"
     ],
-    lists:flatmap(fun(DbName) ->
-        lists:map(fun(Format) ->
-            filename:join("/srv/data", io_lib:format(Format, [DbName]))
-        end, Formats)
-    end, DbNames).
+    lists:flatmap(
+        fun(DbName) ->
+            lists:map(
+                fun(Format) ->
+                    filename:join("/srv/data", io_lib:format(Format, [DbName]))
+                end,
+                Formats
+            )
+        end,
+        DbNames
+    ).
 
 -endif.
