@@ -14,23 +14,19 @@
 
 -module(couch_log_config).
 
-
 -export([
     init/0,
     reconfigure/0,
     get/1
 ]).
 
-
 -define(MOD_NAME, couch_log_config_dyn).
 -define(ERL_FILE, "couch_log_config_dyn.erl").
 
-
 -spec init() -> ok.
 init() ->
     reconfigure().
 
-
 -spec reconfigure() -> ok.
 reconfigure() ->
     {ok, ?MOD_NAME, Bin} = compile:forms(forms(), [verbose, report_errors]),
@@ -38,12 +34,10 @@ reconfigure() ->
     {module, ?MOD_NAME} = code:load_binary(?MOD_NAME, ?ERL_FILE, Bin),
     ok.
 
-
 -spec get(atom()) -> term().
 get(Key) ->
     ?MOD_NAME:get(Key).
 
-
 -spec entries() -> [string()].
 entries() ->
     [
@@ -52,17 +46,19 @@ entries() ->
         {max_message_size, "max_message_size", "16000"},
         {strip_last_msg, "strip_last_msg", "true"},
         {filter_fields, "filter_fields", "[pid, registered_name, error_info, messages]"}
-     ].
-
+    ].
 
 -spec forms() -> [erl_syntax:syntaxTree()].
 forms() ->
-    GetFunClauses = lists:map(fun({FunKey, CfgKey, Default}) ->
-        FunVal = transform(FunKey, config:get("log", CfgKey, Default)),
-        Patterns = [erl_syntax:abstract(FunKey)],
-        Bodies = [erl_syntax:abstract(FunVal)],
-        erl_syntax:clause(Patterns, none, Bodies)
-    end, entries()),
+    GetFunClauses = lists:map(
+        fun({FunKey, CfgKey, Default}) ->
+            FunVal = transform(FunKey, config:get("log", CfgKey, Default)),
+            Patterns = [erl_syntax:abstract(FunKey)],
+            Bodies = [erl_syntax:abstract(FunVal)],
+            erl_syntax:clause(Patterns, none, Bodies)
+        end,
+        entries()
+    ),
 
     Statements = [
         % -module(?MOD_NAME)
@@ -74,11 +70,14 @@ forms() ->
         % -export([lookup/1]).
         erl_syntax:attribute(
             erl_syntax:atom(export),
-            [erl_syntax:list([
-                erl_syntax:arity_qualifier(
-                    erl_syntax:atom(get),
-                    erl_syntax:integer(1))
-            ])]
+            [
+                erl_syntax:list([
+                    erl_syntax:arity_qualifier(
+                        erl_syntax:atom(get),
+                        erl_syntax:integer(1)
+                    )
+                ])
+            ]
         ),
 
         % list(Key) -> Value.
@@ -86,27 +85,22 @@ forms() ->
     ],
     [erl_syntax:revert(X) || X <- Statements].
 
-
 transform(level, LevelStr) ->
     couch_log_util:level_to_atom(LevelStr);
-
 transform(level_int, LevelStr) ->
     Level = couch_log_util:level_to_atom(LevelStr),
     couch_log_util:level_to_integer(Level);
-
 transform(max_message_size, SizeStr) ->
     try list_to_integer(SizeStr) of
         Size -> Size
-    catch _:_ ->
-        16000
+    catch
+        _:_ ->
+            16000
     end;
-
 transform(strip_last_msg, "false") ->
     false;
-
 transform(strip_last_msg, _) ->
     true;
-
 transform(filter_fields, FieldsStr) ->
     Default = [pid, registered_name, error_info, messages],
     case parse_term(FieldsStr) of
@@ -121,7 +115,6 @@ transform(filter_fields, FieldsStr) ->
             Default
     end.
 
-
 parse_term(List) ->
     {ok, Tokens, _} = erl_scan:string(List ++ "."),
     erl_parse:parse_term(Tokens).
