@@ -14,11 +14,9 @@
 -compile(export_all).
 -compile(nowarn_export_all).
 
-
 -include_lib("eunit/include/eunit.hrl").
 -include_lib("couch/include/couch_db.hrl").
 
-
 -define(TEST_MODULES, [
     cpse_test_open_close_delete,
     cpse_test_get_set_props,
@@ -36,29 +34,27 @@
     cpse_test_purge_seqs
 ]).
 
-
 -define(SHUTDOWN_TIMEOUT, 5000).
 -define(COMPACTOR_TIMEOUT, 50000).
 -define(ATTACHMENT_WRITE_TIMEOUT, 10000).
 -define(MAKE_DOC_SUMMARY_TIMEOUT, 5000).
 
-
 create_tests(EngineApp, Extension) ->
     create_tests(EngineApp, EngineApp, Extension).
 
-
 create_tests(EngineApp, EngineModule, Extension) ->
     TestEngine = {EngineApp, EngineModule, Extension},
     application:set_env(couch, test_engine, TestEngine),
-    lists:map(fun(TestMod) ->
-        {atom_to_list(TestMod), cpse_gather:module(TestMod)}
-    end, ?TEST_MODULES).
-
+    lists:map(
+        fun(TestMod) ->
+            {atom_to_list(TestMod), cpse_gather:module(TestMod)}
+        end,
+        ?TEST_MODULES
+    ).
 
 setup_all() ->
     setup_all([]).
 
-
 setup_all(ExtraApps) ->
     Ctx = test_util:start_couch(ExtraApps),
     {ok, {_, EngineMod, Extension}} = application:get_env(couch, test_engine),
@@ -68,20 +64,16 @@ setup_all(ExtraApps) ->
     config:set("mem3", "replicate_purges", "true", false),
     Ctx.
 
-
 teardown_all(Ctx) ->
     test_util:stop_couch(Ctx).
 
-
 rootdir() ->
     config:get("couchdb", "database_dir", ".").
 
-
 dbname() ->
     UUID = couch_uuids:random(),
     <<"db-", UUID/binary>>.
 
-
 get_engine() ->
     case application:get_env(couch, test_engine) of
         {ok, {_App, _Mod, Extension}} ->
@@ -90,21 +82,17 @@ get_engine() ->
             <<"couch">>
     end.
 
-
 create_db() ->
     create_db(dbname()).
 
-
 create_db(DbName) ->
     Engine = get_engine(),
     couch_db:create(DbName, [{engine, Engine}, ?ADMIN_CTX]).
 
-
 open_db(DbName) ->
     Engine = get_engine(),
     couch_db:open_int(DbName, [{engine, Engine}, ?ADMIN_CTX]).
 
-
 shutdown_db(Db) ->
     Pid = couch_db:get_pid(Db),
     Ref = erlang:monitor(process, Pid),
@@ -116,38 +104,47 @@ shutdown_db(Db) ->
         erlang:error(database_shutdown_timeout)
     end,
     test_util:wait(fun() ->
-        case ets:member(couch_server:couch_dbs(couch_db:name(Db)),
-          couch_db:name(Db)) of
+        case
+            ets:member(
+                couch_server:couch_dbs(couch_db:name(Db)),
+                couch_db:name(Db)
+            )
+        of
             true -> wait;
             false -> ok
         end
     end).
 
-
 save_doc(DbName, Json) ->
     {ok, [Rev]} = save_docs(DbName, [Json], []),
     {ok, Rev}.
 
-
 save_docs(DbName, JsonDocs) ->
     save_docs(DbName, JsonDocs, []).
 
-
 save_docs(DbName, JsonDocs, Options) ->
-    Docs = lists:map(fun(JDoc) ->
-        couch_doc:from_json_obj(?JSON_DECODE(?JSON_ENCODE(JDoc)))
-    end, JsonDocs),
+    Docs = lists:map(
+        fun(JDoc) ->
+            couch_doc:from_json_obj(?JSON_DECODE(?JSON_ENCODE(JDoc)))
+        end,
+        JsonDocs
+    ),
     Opts = [full_commit | Options],
     {ok, Db} = couch_db:open_int(DbName, []),
     try
-        case lists:member(replicated_changes, Options) of
+        case lists:member(?REPLICATED_CHANGES, Options) of
             true ->
                 {ok, []} = couch_db:update_docs(
-                        Db, Docs, Opts, replicated_changes),
-                {ok, lists:map(fun(Doc) ->
-                    {Pos, [RevId | _]} = Doc#doc.revs,
-                    {Pos, RevId}
-                end, Docs)};
+                    Db, Docs, Opts, ?REPLICATED_CHANGES
+                ),
+                {ok,
+                    lists:map(
+                        fun(Doc) ->
+                            {Pos, [RevId | _]} = Doc#doc.revs,
+                            {Pos, RevId}
+                        end,
+                        Docs
+                    )};
             false ->
                 {ok, Resp} = couch_db:update_docs(Db, Docs, Opts),
                 {ok, [Rev || {ok, Rev} <- Resp]}
@@ -156,7 +153,6 @@ save_docs(DbName, JsonDocs, Options) ->
         couch_db:close(Db)
     end.
 
-
 open_doc(DbName, DocId0) ->
     DocId = ?JSON_DECODE(?JSON_ENCODE(DocId0)),
     {ok, Db} = couch_db:open_int(DbName, []),
@@ -166,15 +162,16 @@ open_doc(DbName, DocId0) ->
         couch_db:close(Db)
     end.
 
-
 purge(DbName, PurgeInfos) ->
     purge(DbName, PurgeInfos, []).
 
-
 purge(DbName, PurgeInfos0, Options) when is_list(PurgeInfos0) ->
-    PurgeInfos = lists:map(fun({UUID, DocIdJson, Revs}) ->
-        {UUID, ?JSON_DECODE(?JSON_ENCODE(DocIdJson)), Revs}
-    end, PurgeInfos0),
+    PurgeInfos = lists:map(
+        fun({UUID, DocIdJson, Revs}) ->
+            {UUID, ?JSON_DECODE(?JSON_ENCODE(DocIdJson)), Revs}
+        end,
+        PurgeInfos0
+    ),
     {ok, Db} = couch_db:open_int(DbName, []),
     try
         couch_db:purge_docs(Db, PurgeInfos, Options)
@@ -182,31 +179,29 @@ purge(DbName, PurgeInfos0, Options) when is_list(PurgeInfos0) ->
         couch_db:close(Db)
     end.
 
-
 uuid() ->
     couch_uuids:random().
 
-
 assert_db_props(Module, Line, DbName, Props) when is_binary(DbName) ->
     {ok, Db} = couch_db:open_int(DbName, []),
     try
         assert_db_props(Module, Line, Db, Props)
-    catch error:{assertEqual, Props} ->
-        {_, Rest} = proplists:split(Props, [module, line]),
-        erlang:error({assertEqual, [{module, Module}, {line, Line} | Rest]})
+    catch
+        error:{assertEqual, Props} ->
+            {_, Rest} = proplists:split(Props, [module, line]),
+            erlang:error({assertEqual, [{module, Module}, {line, Line} | Rest]})
     after
         couch_db:close(Db)
     end;
-
 assert_db_props(Module, Line, Db, Props) ->
     try
         assert_each_prop(Db, Props)
-    catch error:{assertEqual, Props} ->
-        {_, Rest} = proplists:split(Props, [module, line]),
-        erlang:error({assertEqual, [{module, Module}, {line, Line} | Rest]})
+    catch
+        error:{assertEqual, Props} ->
+            {_, Rest} = proplists:split(Props, [module, line]),
+            erlang:error({assertEqual, [{module, Module}, {line, Line} | Rest]})
     end.
 
-
 assert_each_prop(_Db, []) ->
     ok;
 assert_each_prop(Db, [{doc_count, Expect} | Rest]) ->
@@ -234,51 +229,47 @@ assert_each_prop(Db, [{purge_infos, Expect} | Rest]) ->
     ?assertEqual(Expect, lists:reverse(PurgeInfos)),
     assert_each_prop(Db, Rest).
 
-
 aep_changes(_A, Acc) ->
     {ok, Acc + 1}.
 
-
 aep_fold({_PSeq, UUID, Id, Revs}, Acc) ->
     {ok, [{UUID, Id, Revs} | Acc]}.
 
-
 apply_actions(DbName, Actions) when is_binary(DbName) ->
     {ok, Db0} = couch_db:open_int(DbName, [?ADMIN_CTX]),
     {ok, Db1} = apply_actions(Db0, Actions),
     couch_db:close(Db1),
     ok;
-
 apply_actions(Db, []) ->
     {ok, Db};
-
 apply_actions(Db, [Action | Rest]) ->
     {ok, NewDb} = apply_action(Db, Action),
     apply_actions(NewDb, Rest).
 
-
 apply_action(Db, {batch, BatchActions}) ->
     apply_batch(Db, BatchActions);
-
 apply_action(Db, Action) ->
     apply_batch(Db, [Action]).
 
-
 apply_batch(Db, Actions) ->
     AccIn = {[], [], [], []},
-    AccOut = lists:foldl(fun(Action, Acc) ->
-        {DocAcc, ConfAcc, LDocAcc, PurgeAcc} = Acc,
-        case gen_write(Db, Action) of
-            {update, Doc} ->
-                {[Doc | DocAcc], ConfAcc, LDocAcc, PurgeAcc};
-            {conflict, Doc} ->
-                {DocAcc, [Doc | ConfAcc], LDocAcc, PurgeAcc};
-            {local, Doc} ->
-                {DocAcc, ConfAcc, [Doc | LDocAcc], PurgeAcc};
-            {purge, PurgeInfo} ->
-                {DocAcc, ConfAcc, LDocAcc, [PurgeInfo | PurgeAcc]}
-        end
-    end, AccIn, Actions),
+    AccOut = lists:foldl(
+        fun(Action, Acc) ->
+            {DocAcc, ConfAcc, LDocAcc, PurgeAcc} = Acc,
+            case gen_write(Db, Action) of
+                {update, Doc} ->
+                    {[Doc | DocAcc], ConfAcc, LDocAcc, PurgeAcc};
+                {conflict, Doc} ->
+                    {DocAcc, [Doc | ConfAcc], LDocAcc, PurgeAcc};
+                {local, Doc} ->
+                    {DocAcc, ConfAcc, [Doc | LDocAcc], PurgeAcc};
+                {purge, PurgeInfo} ->
+                    {DocAcc, ConfAcc, LDocAcc, [PurgeInfo | PurgeAcc]}
+            end
+        end,
+        AccIn,
+        Actions
+    ),
 
     {Docs0, Conflicts0, LDocs0, PurgeInfos0} = AccOut,
     Docs = lists:reverse(Docs0),
@@ -290,40 +281,40 @@ apply_batch(Db, Actions) ->
     false = lists:member(conflict, Resp),
     {ok, Db1} = couch_db:reopen(Db),
 
-    {ok, []} = couch_db:update_docs(Db, Conflicts, [], replicated_changes),
+    {ok, []} = couch_db:update_docs(Db, Conflicts, [], ?REPLICATED_CHANGES),
     {ok, Db2} = couch_db:reopen(Db1),
 
-    if PurgeInfos == [] -> ok; true ->
-        {ok, _} = couch_db:purge_docs(Db2, PurgeInfos)
+    if
+        PurgeInfos == [] -> ok;
+        true -> {ok, _} = couch_db:purge_docs(Db2, PurgeInfos)
     end,
     couch_db:reopen(Db2).
 
-
 gen_write(Db, {Action, {<<"_local/", _/binary>> = DocId, Body}}) ->
-    PrevRev = case couch_db:open_doc(Db, DocId) of
-        {not_found, _} ->
-            0;
-        {ok, #doc{revs = {0, []}}} ->
-            0;
-        {ok, #doc{revs = {0, [RevStr | _]}}} ->
-            binary_to_integer(RevStr)
-    end,
-    {RevId, Deleted} = case Action of
-        Action when Action == create; Action == update ->
-            {PrevRev + 1, false};
-        delete ->
-            {0, true}
-    end,
+    PrevRev =
+        case couch_db:open_doc(Db, DocId) of
+            {not_found, _} ->
+                0;
+            {ok, #doc{revs = {0, []}}} ->
+                0;
+            {ok, #doc{revs = {0, [RevStr | _]}}} ->
+                binary_to_integer(RevStr)
+        end,
+    {RevId, Deleted} =
+        case Action of
+            Action when Action == create; Action == update ->
+                {PrevRev + 1, false};
+            delete ->
+                {0, true}
+        end,
     {local, #doc{
         id = DocId,
         revs = {0, [list_to_binary(integer_to_list(RevId))]},
         body = Body,
         deleted = Deleted
     }};
-
 gen_write(Db, {Action, {DocId, Body}}) ->
     gen_write(Db, {Action, {DocId, Body, []}});
-
 gen_write(Db, {create, {DocId, Body, Atts}}) ->
     {not_found, _} = couch_db:open_doc(Db, DocId),
     {update, #doc{
@@ -333,11 +324,13 @@ gen_write(Db, {create, {DocId, Body, Atts}}) ->
         body = Body,
         atts = Atts
     }};
-
 gen_write(_Db, {purge, {DocId, PrevRevs0, _}}) ->
-    PrevRevs = if is_list(PrevRevs0) -> PrevRevs0; true -> [PrevRevs0] end,
+    PrevRevs =
+        if
+            is_list(PrevRevs0) -> PrevRevs0;
+            true -> [PrevRevs0]
+        end,
     {purge, {couch_uuids:random(), DocId, PrevRevs}};
-
 gen_write(Db, {Action, {DocId, Body, Atts}}) ->
     #full_doc_info{} = PrevFDI = couch_db:get_full_doc_info(Db, DocId),
 
@@ -351,16 +344,18 @@ gen_write(Db, {Action, {DocId, Body, Atts}}) ->
 
     NewRev = gen_rev(Action, DocId, PrevRev, Body, Atts),
 
-    Deleted = case Action of
-        update -> false;
-        conflict -> false;
-        delete -> true
-    end,
+    Deleted =
+        case Action of
+            update -> false;
+            conflict -> false;
+            delete -> true
+        end,
 
-    Type = case Action of
-        conflict -> conflict;
-        _ -> update
-    end,
+    Type =
+        case Action of
+            conflict -> conflict;
+            _ -> update
+        end,
 
     {Type, #doc{
         id = DocId,
@@ -370,7 +365,6 @@ gen_write(Db, {Action, {DocId, Body, Atts}}) ->
         atts = Atts
     }}.
 
-
 gen_rev(A, DocId, {Pos, Rev}, Body, Atts) when A == update; A == delete ->
     NewRev = couch_hash:md5_hash(term_to_binary({DocId, Rev, Body, Atts})),
     {Pos + 1, [NewRev, Rev]};
@@ -379,26 +373,24 @@ gen_rev(conflict, DocId, _, Body, Atts) ->
     NewRev = couch_hash:md5_hash(term_to_binary({DocId, UUID, Body, Atts})),
     {1, [NewRev]}.
 
-
 prep_atts(_Db, []) ->
     [];
-
 prep_atts(Db, [{FileName, Data} | Rest]) ->
     {_, Ref} = spawn_monitor(fun() ->
         {ok, Stream} = couch_db:open_write_stream(Db, []),
         exit(write_att(Stream, FileName, Data, Data))
     end),
-    Att = receive
-        {'DOWN', Ref, _, _, {{no_catch, not_supported}, _}} ->
-            throw(not_supported);
-        {'DOWN', Ref, _, _, Resp} ->
-            Resp
+    Att =
+        receive
+            {'DOWN', Ref, _, _, {{no_catch, not_supported}, _}} ->
+                throw(not_supported);
+            {'DOWN', Ref, _, _, Resp} ->
+                Resp
         after ?ATTACHMENT_WRITE_TIMEOUT ->
             erlang:error(attachment_write_timeout)
-    end,
+        end,
     [Att | prep_atts(Db, Rest)].
 
-
 write_att(Stream, FileName, OrigData, <<>>) ->
     {StreamEngine, Len, Len, Md5, Md5} = couch_stream:close(Stream),
     couch_util:check_md5(Md5, couch_hash:md5_hash(OrigData)),
@@ -412,26 +404,24 @@ write_att(Stream, FileName, OrigData, <<>>) ->
         {md5, Md5},
         {encoding, identity}
     ]);
-
 write_att(Stream, FileName, OrigData, Data) ->
-    {Chunk, Rest} = case size(Data) > 4096 of
-        true ->
-            <<Head:4096/binary, Tail/binary>> = Data,
-            {Head, Tail};
-        false ->
-            {Data, <<>>}
-    end,
+    {Chunk, Rest} =
+        case size(Data) > 4096 of
+            true ->
+                <<Head:4096/binary, Tail/binary>> = Data,
+                {Head, Tail};
+            false ->
+                {Data, <<>>}
+        end,
     ok = couch_stream:write(Stream, Chunk),
     write_att(Stream, FileName, OrigData, Rest).
 
-
 prev_rev(#full_doc_info{} = FDI) ->
     #doc_info{
         revs = [#rev_info{} = PrevRev | _]
     } = couch_doc:to_doc_info(FDI),
     PrevRev.
 
-
 db_as_term(Db) ->
     db_as_term(Db, compact).
 
@@ -439,7 +429,6 @@ db_as_term(DbName, Type) when is_binary(DbName) ->
     couch_util:with_db(DbName, fun(Db) ->
         db_as_term(Db, Type)
     end);
-
 db_as_term(Db, Type) ->
     [
         {props, db_props_as_term(Db, Type)},
@@ -449,7 +438,6 @@ db_as_term(Db, Type) ->
         {purged_docs, db_purged_docs_as_term(Db)}
     ].
 
-
 db_props_as_term(Db, Type) ->
     Props0 = [
         get_doc_count,
@@ -463,27 +451,36 @@ db_props_as_term(Db, Type) ->
         get_uuid,
         get_epochs
     ],
-    Props = if Type /= replication -> Props0; true ->
-        Props0 -- [get_uuid]
-    end,
-    lists:map(fun(Fun) ->
-        {Fun, couch_db_engine:Fun(Db)}
-    end, Props).
-
+    Props =
+        if
+            Type /= replication -> Props0;
+            true -> Props0 -- [get_uuid]
+        end,
+    lists:map(
+        fun(Fun) ->
+            {Fun, couch_db_engine:Fun(Db)}
+        end,
+        Props
+    ).
 
 db_docs_as_term(Db) ->
     FoldFun = fun(FDI, Acc) -> {ok, [FDI | Acc]} end,
     {ok, FDIs} = couch_db:fold_docs(Db, FoldFun, [], []),
-    lists:reverse(lists:map(fun(FDI) ->
-        fdi_to_term(Db, FDI)
-    end, FDIs)).
-
+    lists:reverse(
+        lists:map(
+            fun(FDI) ->
+                fdi_to_term(Db, FDI)
+            end,
+            FDIs
+        )
+    ).
 
 db_local_docs_as_term(Db, Type) ->
     FoldFun = fun(Doc, Acc) ->
         case Doc#doc.id of
-            <<?LOCAL_DOC_PREFIX, "purge-mem3", _/binary>>
-                when Type == replication ->
+            <<?LOCAL_DOC_PREFIX, "purge-mem3", _/binary>> when
+                Type == replication
+            ->
                 {ok, Acc};
             _ ->
                 {ok, [Doc | Acc]}
@@ -492,14 +489,17 @@ db_local_docs_as_term(Db, Type) ->
     {ok, LDocs} = couch_db:fold_local_docs(Db, FoldFun, [], []),
     lists:reverse(LDocs).
 
-
 db_changes_as_term(Db) ->
     FoldFun = fun(FDI, Acc) -> {ok, [FDI | Acc]} end,
     {ok, Changes} = couch_db:fold_changes(Db, 0, FoldFun, [], []),
-    lists:reverse(lists:map(fun(FDI) ->
-        fdi_to_term(Db, FDI)
-    end, Changes)).
-
+    lists:reverse(
+        lists:map(
+            fun(FDI) ->
+                fdi_to_term(Db, FDI)
+            end,
+            Changes
+        )
+    ).
 
 db_purged_docs_as_term(Db) ->
     InitPSeq = couch_db_engine:get_oldest_purge_seq(Db) - 1,
@@ -507,18 +507,22 @@ db_purged_docs_as_term(Db) ->
         {ok, [{PSeq, UUID, Id, Revs} | Acc]}
     end,
     {ok, PDocs} = couch_db_engine:fold_purge_infos(
-            Db, InitPSeq, FoldFun, [], []),
+        Db, InitPSeq, FoldFun, [], []
+    ),
     lists:reverse(PDocs).
 
-
 fdi_to_term(Db, FDI) ->
     #full_doc_info{
         id = DocId,
         rev_tree = OldTree
     } = FDI,
-    {NewRevTree, _} = couch_key_tree:mapfold(fun(Rev, Node, Type, Acc) ->
-        tree_to_term(Rev, Node, Type, Acc, DocId)
-    end, Db, OldTree),
+    {NewRevTree, _} = couch_key_tree:mapfold(
+        fun(Rev, Node, Type, Acc) ->
+            tree_to_term(Rev, Node, Type, Acc, DocId)
+        end,
+        Db,
+        OldTree
+    ),
     FDI#full_doc_info{
         rev_tree = NewRevTree,
         % Blank out sizes because we allow storage
@@ -530,10 +534,8 @@ fdi_to_term(Db, FDI) ->
         }
     }.
 
-
 tree_to_term(_Rev, _Leaf, branch, Acc, _DocId) ->
     {?REV_MISSING, Acc};
-
 tree_to_term({Pos, RevId}, #leaf{} = Leaf, leaf, Db, DocId) ->
     #leaf{
         deleted = Deleted,
@@ -549,13 +551,17 @@ tree_to_term({Pos, RevId}, #leaf{} = Leaf, leaf, Db, DocId) ->
 
     Doc1 = couch_db_engine:read_doc_body(Db, Doc0),
 
-    Body = if not is_binary(Doc1#doc.body) -> Doc1#doc.body; true ->
-        couch_compress:decompress(Doc1#doc.body)
-    end,
+    Body =
+        if
+            not is_binary(Doc1#doc.body) -> Doc1#doc.body;
+            true -> couch_compress:decompress(Doc1#doc.body)
+        end,
 
-    Atts1 = if not is_binary(Doc1#doc.atts) -> Doc1#doc.atts; true ->
-        couch_compress:decompress(Doc1#doc.atts)
-    end,
+    Atts1 =
+        if
+            not is_binary(Doc1#doc.atts) -> Doc1#doc.atts;
+            true -> couch_compress:decompress(Doc1#doc.atts)
+        end,
 
     StreamSrc = fun(Sp) -> couch_db:open_read_stream(Db, Sp) end,
     Atts2 = [couch_att:from_disk_term(StreamSrc, Att) || Att <- Atts1],
@@ -568,34 +574,25 @@ tree_to_term({Pos, RevId}, #leaf{} = Leaf, leaf, Db, DocId) ->
     },
     {NewLeaf, Db}.
 
-
 att_to_term(Att) ->
     Bin = couch_att:to_binary(Att),
     couch_att:store(data, Bin, Att).
 
-
 term_diff(T1, T2) when is_tuple(T1), is_tuple(T2) ->
     tuple_diff(tuple_to_list(T1), tuple_to_list(T2));
-
 term_diff(L1, L2) when is_list(L1), is_list(L2) ->
     list_diff(L1, L2);
-
 term_diff(V1, V2) when V1 == V2 ->
     nodiff;
-
 term_diff(V1, V2) ->
     {V1, V2}.
 
-
 tuple_diff([], []) ->
     nodiff;
-
 tuple_diff([T1 | _], []) ->
     {longer, T1};
-
 tuple_diff([], [T2 | _]) ->
     {shorter, T2};
-
 tuple_diff([T1 | R1], [T2 | R2]) ->
     case term_diff(T1, T2) of
         nodiff ->
@@ -604,16 +601,12 @@ tuple_diff([T1 | R1], [T2 | R2]) ->
             {T1, Else}
     end.
 
-
 list_diff([], []) ->
     nodiff;
-
 list_diff([T1 | _], []) ->
     {longer, T1};
-
 list_diff([], [T2 | _]) ->
     {shorter, T2};
-
 list_diff([T1 | R1], [T2 | R2]) ->
     case term_diff(T1, T2) of
         nodiff ->
@@ -622,7 +615,6 @@ list_diff([T1 | R1], [T2 | R2]) ->
             {T1, Else}
     end.
 
-
 compact(Db) ->
     {ok, Pid} = couch_db:start_compact(Db),
     Ref = erlang:monitor(process, Pid),
@@ -656,7 +648,6 @@ compact(Db) ->
         end
     end).
 
-
 with_config(Config, Fun) ->
     OldConfig = apply_config(Config),
     try
@@ -665,10 +656,8 @@ with_config(Config, Fun) ->
         apply_config(OldConfig)
     end.
 
-
 apply_config([]) ->
     [];
-
 apply_config([{Section, Key, Value} | Rest]) ->
     Orig = config:get(Section, Key),
     case Value of
