@@ -61,8 +61,10 @@ check_nodelist() ->
 check_local_dbs() ->
     LocalDbs = mem3_sync:local_dbs(),
     {ok, _} = couch_server:create(<<"_users">>, []),
-    ?assertEqual(lists:append(LocalDbs, [<<"_users">>]),
-        mem3_sync:local_dbs()).
+    ?assertEqual(
+        lists:append(LocalDbs, [<<"_users">>]),
+        mem3_sync:local_dbs()
+    ).
 
 cleanup() ->
     application:stop(mem3),
